OC.L10N.register(
    "spreed",
    {
    "a conversation" : "یک گفتگو",
    "(Duration %s)" : "(مدت زمان %s)",
    "You attended a call with {user1}" : "شما در یک تماس با {user1} شرکت کردید",
    "_%n guest_::_%n guests_" : ["ŸÖ€åŸáŸÖÿßŸÜ %n","ŸÖ€åŸáŸÖÿßŸÜ Ÿáÿß %n"],
    "You attended a call with {user1} and {user2}" : "شما در یک تماس با {user1} و {user2} شرکت کردید",
    "You attended a call with {user1}, {user2} and {user3}" : "شما در یک تماس با {user1}، {user2} و {user3} شرکت کردید",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "شما در یک تماس با {user1}، {user2}، {user3} و {user4} شرکت کردید",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "شما در یک تماس با {user1}، {user2}، {user3}، {user4} و {user5} شرکت کردید",
    "_%n other_::_%n others_" : ["ÿØ€å⁄Øÿ± %n","ÿØ€å⁄Øÿ±ÿßŸÜ %n"],
    "{actor} invited you to {call}" : "{actor} شما را به {call} دعوت کرد",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "شما به یک <strong>گفتگو</strong> دعوت شده‌اید یا یک <strong>تماس</strong> داشته‌اید",
    "Other activities" : "فعالیت‌های دیگر",
    "Talk" : "صحبت",
    "Guest" : "مهمان",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## به نکست‌کلود تاک خوش آمدید!",
    "## New in Talk %s" : "## جدید در تاک %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- مایکروسافت اج و سافاری اکنون می‌توانند برای شرکت در تماس‌های صوتی و تصویری استفاده شوند",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- گفتگوهای دونفره اکنون دائمی هستند و دیگر نمی‌توان به‌طور تصادفی آن‌ها را به گفتگوی گروهی تبدیل کرد. همچنین وقتی یکی از شرکت‌کنندگان گفتگو را ترک کند، گفتگو به‌طور خودکار حذف نمی‌شود. فقط اگر هر دو شرکت‌کننده ترک کنند، گفتگو از سرور حذف می‌شود",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- اکنون می‌توانید با ارسال «@all» در چت، همه شرکت‌کنندگان را مطلع کنید",
    "- With the \"arrow-up\" key you can repost your last message" : "- با کلید «فلش بالا» می‌توانید آخرین پیام خود را دوباره ارسال کنید",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- تاک اکنون می‌تواند دستورات داشته باشد، برای دیدن دستورات پیکربندی‌شده توسط مدیر، «/help» را به عنوان پیام چت ارسال کنید",
    "- With projects you can create quick links between conversations, files and other items" : "- با پروژه‌ها می‌توانید پیوندهای سریع بین گفتگوها، فایل‌ها و موارد دیگر ایجاد کنید",
    "- You can now mention guests in the chat" : "- اکنون می‌توانید مهمانان را در چت منشن کنید",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- گفتگوها اکنون می‌توانند لابی داشته باشند. این به مدیران اجازه می‌دهد برای آماده‌سازی جلسه به چت و تماس بپیوندند، در حالی که کاربران و مهمانان باید منتظر بمانند",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- اکنون می‌توانید مستقیماً به پیام‌ها پاسخ دهید تا به سایر کاربران زمینه بیشتری درباره پیام خود بدهید",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- جستجوی گفتگوها و شرکت‌کنندگان اکنون گفتگوهای موجود شما را نیز فیلتر می‌کند و پیدا کردن گفتگوهای قبلی را بسیار آسان‌تر می‌کند",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- اکنون می‌توانید گروه‌های کاربری سفارشی را به گفتگوها اضافه کنید (در صورت نصب برنامه circles)",
    "- Check out the new grid and call view" : "- نمای جدید شبکه و تماس را بررسی کنید",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- اکنون می‌توانید فایل‌ها را مستقیماً از دستگاه خود به چت آپلود کرده یا بکشید و رها کنید",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- فایل‌های به اشتراک‌گذاشته‌شده اکنون مستقیماً در نمای چت با برنامه‌های نمایش باز می‌شوند",
    "- You can now search for chats and messages in the unified search in the top bar" : "- اکنون می‌توانید چت‌ها و پیام‌ها را در جستجوی یکپارچه در نوار بالا جستجو کنید",
    "- Spice up your messages with emojis from the emoji picker" : "- پیام‌های خود را با ایموجی‌های انتخاب‌گر ایموجی جذاب‌تر کنید",
    "- You can now change your camera and microphone while being in a call" : "- اکنون می‌توانید در حین تماس، دوربین و میکروفون خود را تغییر دهید",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- با افزودن توضیحات به گفتگوهای خود زمینه دهید و آن‌ها را باز کنید تا کاربران واردشده بتوانند پیدا کرده و به آن بپیوندند",
    "- See a read status and send failed messages again" : "- وضعیت خوانده‌شده را ببینید و پیام‌های ناموفق را دوباره ارسال کنید",
    "- Raise your hand in a call with the R key" : "- با کلید R در تماس دست خود را بالا ببرید",
    "- Join the same conversation and call from multiple devices" : "- از چند دستگاه به یک گفتگو و تماس بپیوندید",
    "- Send voice messages, share your location or contact details" : "- پیام‌های صوتی ارسال کنید، موقعیت مکانی یا اطلاعات تماس خود را به اشتراک بگذارید",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- گروه‌ها را به یک گفتگو اضافه کنید و اعضای جدید گروه به‌طور خودکار به عنوان شرکت‌کننده اضافه می‌شوند",
    "- A preview of your audio and video is shown before joining a call" : "- پیش‌نمایش صدا و تصویر شما قبل از پیوستن به تماس نشان داده می‌شود",
    "- You can now blur your background in the newly designed call view" : "- اکنون می‌توانید پس‌زمینه خود را در نمای تماس جدید طراحی‌شده محو کنید",
    "- Moderators can now assign general and individual permissions to participants" : "- مدیران اکنون می‌توانند مجوزهای عمومی و فردی را به شرکت‌کنندگان اختصاص دهند",
    "- You can now react to chat messages" : "- اکنون می‌توانید به پیام‌های چت واکنش نشان دهید",
    "- In the sidebar you can now find an overview of the latest shared items" : "- در نوار کناری اکنون می‌توانید نمای کلی از آخرین موارد به اشتراک‌گذاشته‌شده را پیدا کنید",
    "- Use a poll to collect the opinions of others or settle on a date" : "- از یک نظرسنجی برای جمع‌آوری نظرات دیگران یا توافق بر سر یک تاریخ استفاده کنید",
    "- Configure an expiration time for chat messages" : "- زمان انقضا برای پیام‌های چت تنظیم کنید",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- بدون اطلاع‌رسانی به دیگران در گفتگوهای بزرگ، تماس‌ها را شروع کنید. می‌توانید پس از شروع تماس، اعلان‌های تماس فردی ارسال کنید",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- پیام‌های چت را بدون اطلاع‌رسانی به گیرندگان ارسال کنید (در صورت عدم فوریت)",
    "- Emojis can now be autocompleted by typing a \":\"" : "- ایموجی‌ها اکنون با تایپ «:» به‌طور خودکار تکمیل می‌شوند",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- موارد مختلف را با استفاده از انتخاب‌گر هوشمند جدید با تایپ «/» پیوند دهید",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "مدیران اکنون می‌توانند اتاق‌های فرعی ایجاد کنند (نیازمند بک‌اند با کارایی بالا)",
    "- Calls can now be recorded (requires the High-performance backend)" : "تماس‌ها اکنون قابل ضبط هستند (نیازمند بک‌اند با کارایی بالا)",
    "- Conversations can now have an avatar or emoji as icon" : "گفتگوها اکنون می‌توانند آواتار یا ایموجی به عنوان آیکون داشته باشند",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "پس‌زمینه‌های مجازی علاوه بر پس‌زمینه محو در تماس‌های ویدیویی در دسترس هستند",
    "- Reactions are now available during calls" : "واکنش‌ها اکنون در طول تماس‌ها قابل استفاده هستند",
    "- Typing indicators show which users are currently typing a message" : "نشانگرهای تایپ نشان می‌دهند کدام کاربران در حال تایپ پیام هستند",
    "- Groups can now be mentioned in chats" : "گروه‌ها اکنون می‌توانند در چت‌ها منشن شوند",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "ضبط تماس‌ها به صورت خودکار رونویسی می‌شوند اگر یک برنامه ارائه‌دهنده رونویسی ثبت شده باشد",
    "- Chat messages can be translated if a translation provider app is registered" : "پیام‌های چت می‌توانند ترجمه شوند اگر یک برنامه ارائه‌دهنده ترجمه ثبت شده باشد",
    "- **Markdown** can now be used in _chat_ messages" : "**مارک‌داون** اکنون می‌تواند در پیام‌های _چت_ استفاده شود",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "Webhookها اکنون برای پیاده‌سازی ربات‌ها در دسترس هستند. برای اطلاعات بیشتر به مستندات مراجعه کنید https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "روی یک پیام چت یادآور تنظیم کنید تا بعداً دوباره مطلع شوید",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "از گفتگوی **یادداشت برای خود** برای یادداشت‌برداری و اشتراک اطلاعات بین دستگاه‌های خود استفاده کنید",
    "- Captions allow to send a message with a file at the same time" : "زیرنویس‌ها امکان ارسال همزمان پیام با یک فایل را فراهم می‌کنند",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "ویدیوی گوینده اکنون هنگام اشتراک‌گذاری صفحه قابل مشاهده است و واکنش‌های تماس متحرک هستند",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "پیام‌ها می‌توانند توسط نویسندگان وارد شده و مدیران به مدت ۶ ساعت ویرایش شوند",
    "- Unsent message drafts are now saved in your browser" : "پیش‌نویس‌های پیام‌های ارسال نشده اکنون در مرورگر شما ذخیره می‌شوند",
    "- Text chatting can now be done in a federated way with other Talk servers" : "چت متنی اکنون می‌تواند به صورت فدرال با سایر سرورهای Talk انجام شود",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "مدیران اکنون می‌توانند حساب‌ها و مهمانان را مسدود کنند تا از پیوستن مجدد به گفتگو جلوگیری کنند",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "تماس‌های آینده از رویدادهای تقویم پیوند شده و جایگزین‌های خارج از دفتر اکنون در گفتگوها نشان داده می‌شوند",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "تماس‌ها اکنون می‌توانند به صورت فدرال با سایر سرورهای Talk انجام شوند (نیازمند بک‌اند با کارایی بالا)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "معرفی کلاینت دسکتاپ Nextcloud Talk برای ویندوز، macOS و لینوکس: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "خلاصه‌سازی ضبط تماس‌ها و پیام‌های خوانده نشده در چت‌ها با دستیار Nextcloud",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "جلسات بهبود یافته با شناسایی مهمانان دعوت شده از طریق آدرس ایمیل، وارد کردن لیست شرکت‌کنندگان، پیش‌نویس‌های نظرسنجی و دانلود لیست شرکت‌کنندگان تماس",
    "- Archive conversations to stay focused" : "بایگانی گفتگوها برای حفظ تمرکز",
    "- Schedule a meeting into your calendar from within a conversation" : "برنامه‌ریزی یک جلسه در تقویم خود از داخل یک گفتگو",
    "- Search for messages of the current conversation directly in the right sidebar" : "جستجوی پیام‌های گفتگوی فعلی مستقیماً در نوار کناری سمت راست",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "مشاهده گفتگوهای بیشتر در یک نگاه با لیست فشرده جدید (فعال‌سازی در تنظیمات Talk)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "گفتگوهای جلسه اکنون عنوان و توضیحات را از تقویم همگام‌سازی می‌کنند و با یک فیلتر جستجو پنهان می‌شوند تا نزدیک به زمان شروع",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "گفتگوها را به عنوان حساس در تنظیمات اعلان علامت‌گذاری کنید تا محتوای پیام از لیست گفتگو و اعلان‌ها پنهان شود",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "برای دریافت اعلان‌های فشاری در طول \"مزاحم نشوید\"، گفتگوها را به عنوان مهم علامت‌گذاری کنید",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "شرکت‌کنندگان دیگر را به یک تماس یک‌به‌یک اضافه کنید تا یک تماس گروهی جدید در لحظه ایجاد کنید",
    "- Use threads to keep your chat and discussions organized" : "از رشته‌ها برای سازماندهی چت و بحث‌های خود استفاده کنید",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "رونویسی زنده اکنون در طول تماس در دسترس است (نیازمند ExApp رونویسی زنده و بک‌اند با کارایی بالا)",
    "- Moderators can now pin messages so they are kept at the top" : "مدیران اکنون می‌توانند پیام‌ها را پین کنند تا در بالا نگه داشته شوند",
    "- Schedule a message to send it at a later time" : "زمان‌بندی یک پیام برای ارسال در زمان بعدی",
    "- Conversation tags, grouping and sorting to organize the conversation list" : "برچسب‌های گفتگو، گروه‌بندی و مرتب‌سازی برای سازماندهی لیست گفتگو",
    "- Voice-rooms to connect spontaneously" : "اتاق‌های صوتی برای ارتباط خودجوش",
    "- Presets for quick conversation configuration during creation" : "پیش‌تنظیمات برای پیکربندی سریع گفتگو در حین ایجاد",
    "- Direct calls from profile menus for calls within other apps" : "تماس‌های مستقیم از منوهای پروفایل برای تماس‌های داخل برنامه‌های دیگر",
    "_All %n participant_::_All %n participants_" : ["All %n participant","All %n participants"],
    "Talk updates ✅" : "به روزرسانی های Talk✅ ",
    "Reaction deleted by author" : "واکنش توسط نویسنده حذف شد",
    "{actor} created the conversation" : "{actor} گفتگو را ایجاد کرد",
    "You created the conversation" : "شما گفتگو را ایجاد کردید",
    "System created the conversation" : "سیستم گفتگو را ایجاد کرد",
    "An administrator created the conversation" : "یک مدیر گفتگو را ایجاد کرد",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} نام گفتگو را از \"%1$s\" به \"%2$s\" تغییر داد",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "شما نام گفتگو را از \"%1$s\" به \"%2$s\" تغییر دادید",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "یک مدیر نام گفتگو را از \"%1$s\" به \"%2$s\" تغییر داد",
    "{actor} set the description" : "{actor} توضیحات را تنظیم کرد",
    "You set the description" : "شما توضیحات را تنظیم کردید",
    "An administrator set the description" : "یک مدیر توضیحات را تنظیم کرد",
    "{actor} removed the description" : "{actor} توضیحات را حذف کرد",
    "You removed the description" : "شما توضیحات را حذف کردید",
    "An administrator removed the description" : "یک مدیر توضیحات را حذف کرد",
    "You started a silent call" : "شما یک تماس بی‌صدا شروع کردید",
    "Outgoing silent call" : "تماس بی‌صدای خروجی",
    "{actor} started a silent call" : "{actor} یک تماس بی‌صدا شروع کرد",
    "Incoming silent call" : "تماس بی‌صدای ورودی",
    "You started a call" : "شما یک تماس شروع کردید",
    "Outgoing call" : "تماس خروجی",
    "{actor} started a call" : "{actor} یک تماس شروع کرد",
    "Incoming call" : "تماس ورودی",
    "{actor} joined the call" : "{actor} به تماس پیوست",
    "You joined the call" : "شما به تماس پیوستید",
    "{actor} left the call" : "{actor} تماس را ترک کرد",
    "You left the call" : "شما تماس را ترک کردید",
    "{actor} unlocked the conversation" : "{actor} گفتگو را باز کرد",
    "You unlocked the conversation" : "شما گفتگو را باز کردید",
    "An administrator unlocked the conversation" : "یک مدیر گفتگو را باز کرد",
    "{actor} locked the conversation" : "{actor} گفتگو را قفل کرد",
    "You locked the conversation" : "شما گفتگو را قفل کردید",
    "An administrator locked the conversation" : "یک مدیر گفتگو را قفل کرد",
    "{actor} limited the conversation to the current participants" : "{actor} گفتگو را به شرکت‌کنندگان فعلی محدود کرد",
    "You limited the conversation to the current participants" : "شما گفتگو را به شرکت‌کنندگان فعلی محدود کردید",
    "An administrator limited the conversation to the current participants" : "یک مدیر گفتگو را به شرکت‌کنندگان فعلی محدود کرد",
    "{actor} opened the conversation to registered users" : "{actor} گفتگو را برای کاربران ثبت‌نام‌شده باز کرد",
    "You opened the conversation to registered users" : "شما گفتگو را برای کاربران ثبت‌نام‌شده باز کردید",
    "An administrator opened the conversation to registered users" : "یک مدیر گفتگو را برای کاربران ثبت‌نام‌شده باز کرد",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} گفتگو را برای کاربران ثبت‌نام‌شده و کاربران ایجادشده با برنامه Guests باز کرد",
    "You opened the conversation to registered users and users created with the Guests app" : "شما گفتگو را برای کاربران ثبت‌نام‌شده و کاربران ایجادشده با برنامه Guests باز کردید",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "یک مدیر گفتگو را برای کاربران ثبت‌نام‌شده و کاربران ایجادشده با برنامه Guests باز کرد",
    "The conversation is now open to everyone" : "گفتگو اکنون برای همه باز است",
    "{actor} opened the conversation to everyone" : "{actor} گفتگو را برای همه باز کرد",
    "You opened the conversation to everyone" : "شما گفتگو را برای همه باز کردید",
    "{actor} restricted the conversation to moderators" : "{actor} گفتگو را به مدیران محدود کرد",
    "You restricted the conversation to moderators" : "شما گفتگو را به مدیران محدود کردید",
    "{actor} started breakout rooms" : "{actor} اتاق‌های فرعی را شروع کرد",
    "You started breakout rooms" : "شما اتاق‌های فرعی را شروع کردید",
    "{actor} stopped breakout rooms" : "{actor} اتاق‌های فرعی را متوقف کرد",
    "You stopped breakout rooms" : "شما اتاق‌های فرعی را متوقف کردید",
    "{actor} allowed guests" : "{actor} مهمانان را مجاز کرد",
    "You allowed guests" : "شما مهمانان را مجاز کردید",
    "An administrator allowed guests" : "یک مدیر مهمانان را مجاز کرد",
    "{actor} disallowed guests" : "{actor} مهمانان را غیرمجاز کرد",
    "You disallowed guests" : "شما مهمانان را غیرمجاز کردید",
    "An administrator disallowed guests" : "یک مدیر مهمانان را غیرمجاز کرد",
    "{actor} set a password" : "{actor} یک رمز عبور تنظیم کرد",
    "You set a password" : "شما یک رمز عبور تنظیم کردید",
    "An administrator set a password" : "یک مدیر یک رمز عبور تنظیم کرد",
    "{actor} removed the password" : "{actor} رمز عبور را حذف کرد",
    "You removed the password" : "شما رمز عبور را حذف کردید",
    "An administrator removed the password" : "یک مدیر رمز عبور را حذف کرد",
    "{actor} added {user}" : "{actor} کاربر {user} را اضافه کرد",
    "You joined the conversation" : "شما به گفتگو پیوستید",
    "{actor} joined the conversation" : "{actor} به گفتگو پیوست",
    "You added {user}" : "شما کاربر {user} را اضافه کردید",
    "{actor} added you" : "{actor} شما را اضافه کرد",
    "An administrator added you" : "یک مدیر شما را اضافه کرد",
    "An administrator added {user}" : "یک مدیر کاربر {user} را اضافه کرد",
    "You left the conversation" : "شما گفتگو را ترک کردید",
    "{actor} left the conversation" : "{actor} گفتگو را ترک کرد",
    "{actor} removed {user}" : "{actor} کاربر {user} را حذف کرد",
    "You removed {user}" : "شما کاربر {user} را حذف کردید",
    "{actor} removed you" : "{actor} شما را حذف کرد",
    "An administrator removed you" : "یک مدیر شما را حذف کرد",
    "An administrator removed {user}" : "یک مدیر کاربر {user} را حذف کرد",
    "{actor} invited {federated_user}" : "{actor} کاربر {federated_user} را دعوت کرد",
    "You invited {federated_user}" : "شما کاربر {federated_user} را دعوت کردید",
    "You accepted the invitation" : "شما دعوت را پذیرفتید",
    "{actor} invited you" : "{actor} شما را دعوت کرد",
    "An administrator invited you" : "یک مدیر شما را دعوت کرد",
    "An administrator invited {federated_user}" : "یک مدیر کاربر {federated_user} را دعوت کرد",
    "{federated_user} accepted the invitation" : "کاربر {federated_user} دعوت را پذیرفت",
    "{actor} removed {federated_user}" : "{actor} کاربر {federated_user} را حذف کرد",
    "You removed {federated_user}" : "شما کاربر {federated_user} را حذف کردید",
    "You declined the invitation" : "شما دعوت را رد کردید",
    "An administrator removed {federated_user}" : "یک مدیر کاربر {federated_user} را حذف کرد",
    "{federated_user} declined the invitation" : "کاربر {federated_user} دعوت را رد کرد",
    "{actor} added group {group}" : "{actor} گروه {group} را اضافه کرد",
    "You added group {group}" : "شما گروه {group} را اضافه کردید",
    "An administrator added group {group}" : "یک مدیر گروه {group} را اضافه کرد",
    "{actor} removed group {group}" : "{actor} گروه {group} را حذف کرد",
    "You removed group {group}" : "شما گروه {group} را حذف کردید",
    "An administrator removed group {group}" : "یک مدیر گروه {group} را حذف کرد",
    "{actor} added team {circle}" : "{actor} تیم {circle} را اضافه کرد",
    "You added team {circle}" : "شما تیم {circle} را اضافه کردید",
    "An administrator added team {circle}" : "یک مدیر تیم {circle} را اضافه کرد",
    "{actor} removed team {circle}" : "{actor} تیم {circle} را حذف کرد",
    "You removed team {circle}" : "شما تیم {circle} را حذف کردید",
    "An administrator removed team {circle}" : "یک مدیر تیم {circle} را حذف کرد",
    "{actor} added {phone}" : "{actor} شماره {phone} را اضافه کرد",
    "You added {phone}" : "شما شماره {phone} را اضافه کردید",
    "An administrator added {phone}" : "یک مدیر شماره {phone} را اضافه کرد",
    "{actor} removed {phone}" : "{actor} شماره {phone} را حذف کرد",
    "You removed {phone}" : "شما شماره {phone} را حذف کردید",
    "An administrator removed {phone}" : "یک مدیر شماره {phone} را حذف کرد",
    "{actor} promoted {user} to moderator" : "{actor} کاربر {user} را به مقام ناظر ارتقا داد",
    "You promoted {user} to moderator" : "شما کاربر {user} را به مقام ناظر ارتقا دادید",
    "{actor} promoted you to moderator" : "{actor} شما را به عنوان ناظر ارتقا داد",
    "An administrator promoted you to moderator" : "یک مدیر شما را به عنوان ناظر ارتقا داد",
    "An administrator promoted {user} to moderator" : "یک مدیر {user} را به عنوان ناظر ارتقا داد",
    "{actor} demoted {user} from moderator" : "{actor} {user} را از ناظری تنزل داد",
    "You demoted {user} from moderator" : "شما {user} را از ناظری تنزل دادید",
    "{actor} demoted you from moderator" : "{actor} شما را از ناظری تنزل داد",
    "An administrator demoted you from moderator" : "یک مدیر شما را از ناظری تنزل داد",
    "An administrator demoted {user} from moderator" : "یک مدیر {user} را از ناظری تنزل داد",
    "{actor} shared a file which is no longer available" : "{actor} فایلی را به اشتراک گذاشت که دیگر در دسترس نیست",
    "You shared a file which is no longer available" : "شما فایلی را به اشتراک گذاشتید که دیگر در دسترس نیست",
    "File shares are currently not supported in federated conversations" : "اشتراک‌گذاری فایل در حال حاضر در گفتگوهای فدرال پشتیبانی نمی‌شود",
    "The shared location is malformed" : "مکان به اشتراک‌گذاری‌شده ناقص است",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} Matterbridge را برای همگام‌سازی این گفتگو با چت‌های دیگر راه‌اندازی کرد",
    "You set up Matterbridge to synchronize this conversation with other chats" : "شما Matterbridge را برای همگام‌سازی این گفتگو با چت‌های دیگر راه‌اندازی کردید",
    "{actor} created thread {title}" : "{actor} موضوع {title} را ایجاد کرد",
    "You created thread {title}" : "شما موضوع {title} را ایجاد کردید",
    "{actor} renamed thread {title}" : "{actor} موضوع {title} را تغییر نام داد",
    "You renamed thread {title}" : "شما موضوع {title} را تغییر نام دادید",
    "{actor} updated the Matterbridge configuration" : "{actor} پیکربندی Matterbridge را به‌روزرسانی کرد",
    "You updated the Matterbridge configuration" : "شما پیکربندی Matterbridge را به‌روزرسانی کردید",
    "{actor} removed the Matterbridge configuration" : "{actor} پیکربندی Matterbridge را حذف کرد",
    "You removed the Matterbridge configuration" : "شما پیکربندی Matterbridge را حذف کردید",
    "{actor} started Matterbridge" : "{actor} Matterbridge را شروع کرد",
    "You started Matterbridge" : "شما Matterbridge را شروع کردید",
    "{actor} stopped Matterbridge" : "{actor} Matterbridge را متوقف کرد",
    "You stopped Matterbridge" : "شما Matterbridge را متوقف کردید",
    "{actor} deleted a message" : "{actor} یک پیام را حذف کرد",
    "You deleted a message" : "شما یک پیام را حذف کردید",
    "{actor} edited a message" : "{actor} یک پیام را ویرایش کرد",
    "You edited a message" : "شما یک پیام را ویرایش کردید",
    "{actor} pinned a message" : "{actor} یک پیام را سنجاق کرد",
    "You pinned a message" : "شما یک پیام را سنجاق کردید",
    "{actor} unpinned a message" : "{actor} یک پیام را از سنجاق خارج کرد",
    "Message was automatically unpinned" : "پیام به طور خودکار از سنجاق خارج شد",
    "You unpinned a message" : "شما یک پیام را از سنجاق خارج کردید",
    "{actor} deleted a reaction" : "{actor} یک واکنش را حذف کرد",
    "You deleted a reaction" : "شما یک واکنش را حذف کردید",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["You set the message expiration to %n week","You set the message expiration to %n weeks"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["You set the message expiration to %n day","You set the message expiration to %n days"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["You set the message expiration to %n hour","You set the message expiration to %n hours"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["You set the message expiration to %n minute","You set the message expiration to %n minutes"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} set the message expiration to %n week","{actor} set the message expiration to %n weeks"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} set the message expiration to %n day","{actor} set the message expiration to %n days"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} set the message expiration to %n hour","{actor} set the message expiration to %n hours"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} set the message expiration to %n minute","{actor} set the message expiration to %n minutes"],
    "{actor} disabled message expiration" : "{actor} انقضای پیام را غیرفعال کرد",
    "You disabled message expiration" : "شما انقضای پیام را غیرفعال کردید",
    "{actor} cleared the history of the conversation" : "{actor} تاریخچه گفتگو را پاک کرد",
    "You cleared the history of the conversation" : "شما تاریخچه گفتگو را پاک کردید",
    "{actor} set the conversation picture" : "{actor} تصویر گفتگو را تنظیم کرد",
    "You set the conversation picture" : "شما عکس گفتگو را تنظیم کردید",
    "{actor} removed the conversation picture" : "{actor} عکس گفتگو را حذف کرد",
    "You removed the conversation picture" : "شما عکس گفتگو را حذف کردید",
    "{actor} ended the poll {poll}" : "{actor} نظرسنجی {poll} را پایان داد",
    "You ended the poll {poll}" : "شما نظرسنجی {poll} را پایان دادید",
    "{actor} started the video recording" : "{actor} ضبط ویدیو را شروع کرد",
    "You started the video recording" : "شما ضبط ویدیو را شروع کردید",
    "{actor} stopped the video recording" : "{actor} ضبط ویدیو را متوقف کرد",
    "You stopped the video recording" : "شما ضبط ویدیو را متوقف کردید",
    "{actor} started the audio recording" : "{actor} ضبط صدا را شروع کرد",
    "You started the audio recording" : "شما ضبط صدا را شروع کردید",
    "{actor} stopped the audio recording" : "{actor} ضبط صدا را متوقف کرد",
    "You stopped the audio recording" : "شما ضبط صدا را متوقف کردید",
    "The recording failed" : "ضبط ناموفق بود",
    "Someone voted on the poll {poll}" : "شخصی در نظرسنجی {poll} رأی داد",
    "Message deleted by author" : "پیام توسط نویسنده حذف شد",
    "Message deleted by {actor}" : "پیام توسط {actor} حذف شد",
    "Message deleted by you" : "پیام توسط شما حذف شد",
    "Deleted user" : "کاربر حذف‌شده",
    "Unknown number" : "شماره ناشناس",
    "Administration" : "مدیریت",
    "System" : "سیستم",
    "%s (guest)" : "%s (مهمان)",
    "Missed call" : "تماس بی‌پاسخ",
    "Unanswered call" : "تماس بدون پاسخ",
    "Call ended (Duration {duration})" : "تماس پایان یافت (مدت {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "تماس به دلیل رسیدن به حداکثر مدت مجاز پایان یافت (مدت {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} تماس را پایان داد (مدت {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})","Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Call with %n guest ended (Duration {duration})","Call with %n guests ended (Duration {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} ended the call with %n guest (Duration {duration})","{actor} ended the call with %n guests (Duration {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "تماس با {user1} به دلیل رسیدن به حداکثر مدت مجاز پایان یافت (مدت {duration})",
    "Call with {user1} ended (Duration {duration})" : "تماس با {user1} پایان یافت (مدت {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} تماس با {user1} را پایان داد (مدت {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "تماس با {user1} و {user2} به دلیل رسیدن به حداکثر مدت مجاز پایان یافت (مدت {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "تماس با {user1} و {user2} پایان یافت (مدت {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} تماس با {user1} و {user2} را پایان داد (مدت {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "تماس با {user1}، {user2} و {user3} به دلیل رسیدن به حداکثر مدت مجاز پایان یافت (مدت {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "تماس با {user1}، {user2} و {user3} پایان یافت (مدت {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} تماس با {user1}، {user2} و {user3} را پایان داد (مدت {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "تماس با {user1}، {user2}، {user3} و {user4} به دلیل رسیدن به حداکثر مدت مجاز پایان یافت (مدت {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "تماس با {user1}، {user2}، {user3} و {user4} پایان یافت (مدت {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} تماس با {user1}، {user2}، {user3} و {user4} را پایان داد (مدت {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "تماس با {user1}، {user2}، {user3}، {user4} و {user5} به دلیل رسیدن به حداکثر مدت مجاز پایان یافت (مدت {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "تماس با {user1}، {user2}، {user3}، {user4} و {user5} پایان یافت (مدت {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} تماس با {user1}، {user2}، {user3}، {user4} و {user5} را پایان داد (مدت {duration})",
    "Message of {user} in {conversation}" : "پیام {user} در {conversation}",
    "Message of {user}" : "پیام {user}",
    "Message of a deleted user in {conversation}" : "پیام یک کاربر حذف‌شده در {conversation}",
    "Talk conversations" : "گفتگوهای Talk",
    "Call %s" : "تماس با %s",
    "Chat with %s" : "گفتگو با %s",
    "An error occurred. Please contact your administrator." : "خطایی رخ داد. لطفاً با مدیر خود تماس بگیرید.",
    "App disabled" : "برنامه غیرفعال شد",
    "Conversation subfolders are disabled" : "زیرپوشه‌های گفتگو غیرفعال هستند",
    "Storage quota exceeded" : "سهمیه ذخیره‌سازی تکمیل شد",
    "Could not prepare conversation folder" : "امکان آماده‌سازی پوشه گفتگو وجود نداشت",
    "File not found" : "فایل پیدا نشد",
    "Path must point to a file" : "مسیر باید به یک فایل اشاره کند",
    "File is not inside the conversation draft folder for this room" : "فایل در پوشه پیش‌نویس گفتگوی این اتاق نیست",
    "File is not shared, or shared but not with the user" : "فایل به اشتراک گذاشته نشده، یا به اشتراک گذاشته شده اما با کاربر نیست",
    "No account available to delete." : "حسابی برای حذف موجود نیست",
    "Poll" : "نظرسنجی",
    "Password needs to be set" : "نیاز به تنظیم رمز عبور است",
    "Uploading the file failed" : "بارگذاری فایل ناموفق بود",
    "No image file provided" : "فایل تصویری ارائه نشده است",
    "File is too big" : "فایل بیش از حد بزرگ است",
    "Invalid file provided" : "فایل نامعتبر ارائه شده است",
    "Invalid image" : "تصویر نامعتبر",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "Talk mentions" : "اشاره‌های Talk",
    "More conversations" : "گفتگوهای بیشتر",
    "Say hi to your friends and colleagues!" : "به دوستان و همکارانتان سلام کنید!",
    "No unread mentions" : "اشاره‌های خوانده نشده وجود ندارد",
    "Call in progress" : "تماس در حال انجام",
    "You were mentioned" : "به شما اشاره شد",
    "Write to conversation" : "به گفتگو بنویسید",
    "Writes event information into a conversation of your choice" : "اطلاعات رویداد را در یک گفتگوی دلخواه می‌نویسد",
    "Missing %s field in header line" : "فیلد %s در خط هدر وجود ندارد",
    "Following lines are invalid: %s" : "خطوط زیر نامعتبر هستند: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s شما را به گفتگوی \"%2$s\" دعوت کرد.",
    "You were invited to conversation \"%s\"." : "شما به گفتگوی \"%s\" دعوت شدید.",
    "Conversation invitation" : "دعوتنامه گفتگو",
    "Scheduled time" : "زمان برنامه‌ریزی شده",
    "Description" : "توضیحات",
    "You can also dial-in via phone with the following details" : "همچنین می‌توانید با جزئیات زیر از طریق تلفن وارد شوید",
    "Dial-in information" : "اطلاعات ورود از طریق تلفن",
    "Meeting ID" : "شناسه جلسه",
    "Your PIN" : "PIN شما",
    "Click the button below to join the lobby now." : "برای پیوستن به لابی اکنون روی دکمه زیر کلیک کنید.",
    "Click the link below to join the lobby now." : "برای پیوستن به لابی اکنون روی لینک زیر کلیک کنید.",
    "Join lobby for \"%s\"" : "پیوستن به لابی برای \"%s\"",
    "Click the button below to join the conversation now." : "برای پیوستن به گفتگو اکنون روی دکمه زیر کلیک کنید.",
    "Click the link below to join the conversation now." : "برای پیوستن به گفتگو اکنون روی لینک زیر کلیک کنید.",
    "Join \"%s\"" : "پیوستن به \"%s\"",
    "Meeting" : "جلسه",
    "Password request: %s" : "درخواست رمز عبور: %s",
    "Private conversation" : "گفتگوی خصوصی",
    "Deleted user (%s)" : "کاربر حذف شده (%s)",
    "Failed to upload call recording" : "بارگذاری ضبط تماس ناموفق بود",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "سرور ضبط نتوانست ضبط تماس {call} را بارگذاری کند. لطفاً با مدیریت تماس بگیرید.",
    "Share to chat" : "اشتراک‌گذاری در گفتگو",
    "Dismiss notification" : "رد اعلان",
    "Call recording now available" : "ضبط تماس اکنون در دسترس است",
    "The recording for the call in {call} was uploaded to {file}." : "ضبط تماس در {call} در {file} بارگذاری شد.",
    "Transcript now available" : "رونوشت اکنون در دسترس است",
    "The transcript for the call in {call} was uploaded to {file}." : "رونوشت تماس در {call} در {file} بارگذاری شد.",
    "Failed to transcript call recording" : "رونوشت‌برداری از ضبط تماس ناموفق بود",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "سرور نتوانست رونوشت ضبط در {file} برای تماس در {call} را ایجاد کند. لطفاً با مدیریت تماس بگیرید.",
    "Call summary now available" : "خلاصه تماس اکنون در دسترس است",
    "The summary for the call in {call} was uploaded to {file}." : "خلاصه تماس در {call} در {file} بارگذاری شد.",
    "Failed to summarize call recording" : "خلاصه‌سازی ضبط تماس ناموفق بود",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "سرور نتوانست خلاصه ضبط در {file} برای تماس در {call} را ایجاد کند. لطفاً با مدیریت تماس بگیرید.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} شما را به پیوستن به {roomName} در {remoteServer} دعوت کرد",
    "Accept" : "پذیرفتن",
    "Decline" : "رد کردن",
    "{user1} invited you to a federated conversation" : "{user1} شما را به یک گفتگوی فدرال دعوت کرد",
    "Someone reacted" : "یک نفر واکنش نشان داد",
    "New message" : "پیام جدید",
    "Reminder" : "یادآوری",
    "Someone mentioned you" : "یک نفر شما را منشن کرد",
    "Notification" : "اعلان",
    "Someone reacted in a private conversation" : "یک نفر در یک گفتگوی خصوصی واکنش نشان داد",
    "You received a message in a private conversation" : "شما یک پیام در یک گفتگوی خصوصی دریافت کردید",
    "Reminder in a private conversation" : "یادآوری در یک گفتگوی خصوصی",
    "Someone mentioned you in a private conversation" : "یک نفر شما را در یک گفتگوی خصوصی منشن کرد",
    "Notification in a private conversation" : "اعلان در یک گفتگوی خصوصی",
    "Reminder: You in {call}" : "یادآوری: شما در {call}",
    "Reminder: {user} in {call}" : "یادآوری: {user} در {call}",
    "Reminder: Deleted user in {call}" : "یادآوری: کاربر حذف‌شده در {call}",
    "Reminder: {guest} (guest) in {call}" : "یادآوری: {guest} (مهمان) در {call}",
    "Reminder: Guest in {call}" : "یادآوری: مهمان در {call}",
    "{user} reacted with {reaction}" : "{user} با {reaction} واکنش نشان داد",
    "{user} reacted with {reaction} in {call}" : "{user} با {reaction} در {call} واکنش نشان داد",
    "Deleted user reacted with {reaction} in {call}" : "کاربر حذف‌شده با {reaction} در {call} واکنش نشان داد",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (مهمان) با {reaction} در {call} واکنش نشان داد",
    "Guest reacted with {reaction} in {call}" : "مهمان با {reaction} در {call} واکنش نشان داد",
    "{user} in {call}" : "{user} در {call}",
    "Deleted user in {call}" : "کاربر حذف‌شده در {call}",
    "{guest} (guest) in {call}" : "{guest} (مهمان) در {call}",
    "Guest in {call}" : "مهمان در {call}",
    "{user} sent you a private message" : "{user} یک پیام خصوصی برای شما فرستاد",
    "{user} sent a message in conversation {call}" : "{user} یک پیام در گفتگوی {call} فرستاد",
    "A deleted user sent a message in conversation {call}" : "یک کاربر حذف‌شده یک پیام در گفتگوی {call} فرستاد",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (مهمان) یک پیام در گفتگوی {call} فرستاد",
    "A guest sent a message in conversation {call}" : "یک مهمان یک پیام در گفتگوی {call} فرستاد",
    "{user} replied to your private message" : "{user} به پیام خصوصی شما پاسخ داد",
    "{user} replied to your message in conversation {call}" : "{user} به پیام شما در گفتگوی {call} پاسخ داد",
    "A deleted user replied to your message in conversation {call}" : "یک کاربر حذف‌شده به پیام شما در گفتگوی {call} پاسخ داد",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (مهمان) به پیام شما در گفتگوی {call} پاسخ داد",
    "A guest replied to your message in conversation {call}" : "یک مهمان به پیام شما در گفتگوی {call} پاسخ داد",
    "Reminder: You in private conversation {call}" : "یادآوری: شما در گفتگوی خصوصی {call}",
    "Reminder: A deleted user in private conversation {call}" : "یادآوری: یک کاربر حذف‌شده در گفتگوی خصوصی {call}",
    "Reminder: {user} in private conversation" : "یادآوری: {user} در گفتگوی خصوصی",
    "Reminder: You in conversation {call}" : "یادآوری: شما در گفتگوی {call}",
    "Reminder: {user} in conversation {call}" : "یادآوری: {user} در گفتگوی {call}",
    "Reminder: A deleted user in conversation {call}" : "یادآوری: یک کاربر حذف‌شده در گفتگوی {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "یادآوری: {guest} (مهمان) در گفتگوی {call}",
    "Reminder: A guest in conversation {call}" : "یادآوری: یک مهمان در گفتگوی {call}",
    "{user} reacted with {reaction} to your private message" : "{user} با {reaction} به پیام خصوصی شما واکنش نشان داد",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} با {reaction} به پیام شما در گفتگوی {call} واکنش نشان داد",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "یک کاربر حذف‌شده با {reaction} به پیام شما در گفتگوی {call} واکنش نشان داد",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (مهمان) با {reaction} به پیام شما در گفتگوی {call} واکنش نشان داد",
    "A guest reacted with {reaction} to your message in conversation {call}" : "یک مهمان با {reaction} به پیام شما در گفتگوی {call} واکنش نشان داد",
    "{user} mentioned you in a private conversation" : "{user} در یک گفتگوی خصوصی به شما اشاره کرد",
    "{user} mentioned group {group} in conversation {call}" : "{user} به گروه {group} در گفتگوی {call} اشاره کرد",
    "{user} mentioned team {team} in conversation {call}" : "{user} به تیم {team} در گفتگوی {call} اشاره کرد",
    "{user} mentioned everyone in conversation {call}" : "{user} به همه در گفتگوی {call} اشاره کرد",
    "{user} mentioned you in conversation {call}" : "{user} در گفتگوی {call} به شما اشاره کرد",
    "A deleted user mentioned group {group} in conversation {call}" : "یک کاربر حذف‌شده به گروه {group} در گفتگوی {call} اشاره کرد",
    "A deleted user mentioned team {team} in conversation {call}" : "یک کاربر حذف‌شده به تیم {team} در گفتگوی {call} اشاره کرد",
    "A deleted user mentioned everyone in conversation {call}" : "یک کاربر حذف‌شده به همه در گفتگوی {call} اشاره کرد",
    "A deleted user mentioned you in conversation {call}" : "یک کاربر حذف‌شده در گفتگوی {call} به شما اشاره کرد",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (مهمان) به گروه {group} در گفتگوی {call} اشاره کرد",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (مهمان) به تیم {team} در گفتگوی {call} اشاره کرد",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (مهمان) به همه در گفتگوی {call} اشاره کرد",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (مهمان) در گفتگوی {call} به شما اشاره کرد",
    "A guest mentioned group {group} in conversation {call}" : "یک مهمان به گروه {group} در گفتگوی {call} اشاره کرد",
    "A guest mentioned team {team} in conversation {call}" : "یک مهمان به تیم {team} در گفتگوی {call} اشاره کرد",
    "A guest mentioned everyone in conversation {call}" : "یک مهمان به همه در گفتگوی {call} اشاره کرد",
    "A guest mentioned you in conversation {call}" : "یک مهمان در گفتگوی {call} به شما اشاره کرد",
    "View message" : "مشاهده پیام",
    "Dismiss reminder" : "رد کردن یادآوری",
    "View chat" : "مشاهده گفتگو",
    "{user} invited you to a group conversation: {call}" : "{user} شما را به یک گفتگوی گروهی دعوت کرد: {call}",
    "Join call" : "پیوستن به تماس",
    "Answer call" : "پاسخ به تماس",
    "{user} would like to talk with you" : "{user} می‌خواهد با شما صحبت کند",
    "Call back" : "تماس مجدد",
    "You missed a call from {user}" : "تماس {user} را از دست دادید",
    "Accept call" : "قبول تماس",
    "Incoming phone call from {call}" : "تماس تلفنی ورودی از {call}",
    "You missed a phone call from {call}" : "تماس تلفنی از {call} را از دست دادید",
    "A group call has started in {call}" : "یک تماس گروهی در {call} شروع شد",
    "You missed a group call in {call}" : "یک تماس گروهی در {call} را از دست دادید",
    "{email} is requesting the password to access {file}" : "{email} درخواست رمز عبور برای دسترسی به {file} دارد",
    "{email} tried to request the password to access {file}" : "{email} سعی کرد رمز عبور برای دسترسی به {file} را درخواست کند",
    "Someone is requesting the password to access {file}" : "شخصی درخواست رمز عبور برای دسترسی به {file} دارد",
    "Someone tried to request the password to access {file}" : "شخصی سعی کرد رمز عبور برای دسترسی به {file} را درخواست کند",
    "Open settings" : "باز کردن تنظیمات",
    "Hosted signaling server added" : "سرور سیگنالینگ میزبانی‌شده اضافه شد",
    "The hosted signaling server is now configured and will be used." : "سرور سیگنالینگ میزبانی‌شده اکنون پیکربندی شده و استفاده خواهد شد",
    "Hosted signaling server removed" : "سرور سیگنالینگ میزبانی‌شده حذف شد",
    "The hosted signaling server was removed and will not be used anymore." : "سرور سیگنالینگ میزبانی‌شده حذف شد و دیگر استفاده نخواهد شد",
    "Hosted signaling server changed" : "سرور سیگنالینگ میزبانی‌شده تغییر کرد",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "حساب سرور سیگنالینگ میزبانی‌شده وضعیت خود را از \"{oldstatus}\" به \"{newstatus}\" تغییر داده است",
    "pending" : "در انتظار",
    "active" : "فعال",
    "expired" : "منقضی‌شده",
    "blocked" : "مسدود",
    "error" : "خطا",
    "The certificate of {host} expires in {days} days" : "گواهی {host} در {days} روز منقضی می‌شود",
    "The certificate of {host} expired" : "گواهی {host} منقضی شد",
    "Contact via Talk" : "تماس از طریق Talk",
    "Open Talk" : "باز کردن Talk",
    "Call via Talk" : "تماس صوتی از طریق Talk",
    "Default" : "پیش‌فرض",
    "Send messages, create threads, and start voice and video calls." : "ارسال پیام، ایجاد موضوعات و شروع تماس‌های صوتی و تصویری",
    "Presentation" : "ارائه",
    "Restricted conversation for internal presentations." : "گفتگوی محدود برای ارائه‌های داخلی",
    "Voice room" : "اتاق صوتی",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "مستقیماً به تماس بپیوندید، ایده‌آل برای گفتگوهای سریع یا جلسات خودجوش",
    "Webinar" : "وبینار",
    "Restricted conversation with lobby enabled, ideal for public webinars." : "گفتگوی محدود با لابی فعال، ایده‌آل برای وبینارهای عمومی",
    "Conversations" : "گفتگوها",
    "Messages in current conversation" : "پیام‌ها در گفتگوی فعلی",
    "{user}" : "{user}",
    "Messages" : "پیام‌ها",
    "{user} in {conversation}" : "{user} در {conversation}",
    "Messages in other conversations" : "پیام‌ها در سایر گفتگوها",
    "One-to-one rooms always need to show the other users avatar" : "اتاق‌های یک‌به‌یک همیشه باید آواتار کاربر دیگر را نشان دهند",
    "Invalid emoji character" : "کاراکتر ایموجی نامعتبر",
    "Invalid background color" : "رنگ پس‌زمینه نامعتبر",
    "Avatar image is not square" : "تصویر آواتار مربعی نیست",
    "Room {number}" : "اتاق {number}",
    "Favorites" : "موارد دلخواه",
    "Other" : "سایر",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "درخواست نسخه آزمایشی به دلیل عدم دسترسی به سرور آزمایشی ناموفق بود. لطفاً بعداً دوباره تلاش کنید",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "مشکلی در احراز هویت این نمونه وجود دارد. احتمالاً از بیرون قابل دسترسی نیست تا URL آن تأیید شود",
    "Something unexpected happened." : "اتفاق غیرمنتظره‌ای رخ داد",
    "The URL is invalid." : "URL نامعتبر است",
    "An HTTPS URL is required." : "URL HTTPS الزامی است",
    "The email address is invalid." : "آدرس ایمیل نامعتبر است",
    "The language is invalid." : "زبان نامعتبر است",
    "The country is invalid." : "کشور نامعتبر است",
    "There is a problem with the request of the trial. Please check your logs for further information." : "مشکلی در درخواست نسخه آزمایشی وجود دارد. لطفاً برای اطلاعات بیشتر لاگ‌های خود را بررسی کنید",
    "Too many requests are send from your servers address. Please try again later." : "تعداد زیادی درخواست از آدرس سرور شما ارسال شده است. لطفاً بعداً دوباره تلاش کنید",
    "There is already a trial registered for this Nextcloud instance." : "قبلاً یک نسخه آزمایشی برای این نمونه نکست‌کلود ثبت شده است",
    "Something unexpected happened. Please try again later." : "اتفاق غیرمنتظره‌ای رخ داد. لطفاً بعداً دوباره تلاش کنید",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "درخواست نسخه آزمایشی به دلیل رفتار نادرست سرور آزمایشی ناموفق بود. لطفاً بعداً دوباره تلاش کنید",
    "Trial requested but failed to get account information. Please check back later." : "درخواست آزمایشی انجام شد اما دریافت اطلاعات حساب ممکن نشد. لطفاً بعداً دوباره بررسی کنید.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "در تأیید اعتبار این درخواست مشکلی وجود دارد. احتمالاً از بیرون برای تأیید نشانی اینترنتی آن قابل دسترسی نیست.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "دریافت اطلاعات حساب به دلیل عملکرد نادرست سرور آزمایشی با شکست مواجه شد. لطفاً بعداً دوباره بررسی کنید.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "در دریافت اطلاعات حساب مشکلی وجود دارد. لطفاً برای اطلاعات بیشتر گزارش‌های خود را بررسی کنید.",
    "There is no such account registered." : "چنین حسابی ثبت نشده است.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "دریافت اطلاعات حساب به دلیل عدم دسترسی به سرور آزمایشی با شکست مواجه شد. لطفاً بعداً دوباره بررسی کنید.",
    "Deleting the hosted signaling server account failed. Please check back later." : "حذف حساب سرور سیگنالینگ میزبانی‌شده با شکست مواجه شد. لطفاً بعداً دوباره بررسی کنید.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "حذف حساب به دلیل عملکرد نادرست سرور آزمایشی با شکست مواجه شد. لطفاً بعداً دوباره بررسی کنید.",
    "There is a problem with deleting the account. Please check your logs for further information." : "در حذف حساب مشکلی وجود دارد. لطفاً برای اطلاعات بیشتر گزارش‌های خود را بررسی کنید.",
    "Too many requests are sent from your servers address. Please try again later." : "تعداد زیادی درخواست از نشانی سرور شما ارسال شده است. لطفاً بعداً دوباره تلاش کنید.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "حذف حساب به دلیل عدم دسترسی به سرور آزمایشی با شکست مواجه شد. لطفاً بعداً دوباره بررسی کنید.",
    "Note to self" : "یادداشت شخصی",
    "A place for your private notes, thoughts and ideas" : "جایی برای یادداشت‌ها، افکار و ایده‌های خصوصی شما",
    "Transcript is AI generated and may contain mistakes" : "رونوشت توسط هوش مصنوعی تولید شده است و ممکن است حاوی اشتباه باشد",
    "Summary is AI generated and may contain mistakes" : "خلاصه توسط هوش مصنوعی تولید شده است و ممکن است حاوی اشتباه باشد",
    "Let's get started!" : "بیایید شروع کنیم!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**نکست‌کلود تاک** یک پلتفرم ارتباطی امن و خودمیزبان است که به‌طور یکپارچه با اکوسیستم نکست‌کلود ادغام می‌شود.",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# به نکست‌کلود تاک خوش آمدید",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 متن‌ها را قالب‌بندی کنید تا پیام‌هایی غنی بسازید\n\nدر Nextcloud Talk می‌توانید از نحو Markdown برای قالب‌بندی پیام‌های خود استفاده کنید. برای مثال، قالب‌بندی **پررنگ** یا *کج* اعمال کنید یا `متن‌ها را به‌صورت کد برجسته کنید`. حتی می‌توانید جدول بسازید و به متن خود عنوان اضافه کنید.\n\nنیاز به اصلاح یک غلط تایپی یا تغییر قالب‌بندی دارید؟ با کلیک روی \"ویرایش پیام\" در منوی پیام، پیام خود را ویرایش کنید.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 پیوست‌ها و پیوندها را اضافه کنید\n\nبا استفاده از دکمه \"+\"، پرونده‌هایی را از Nextcloud Hub خود پیوست کنید. موارد را از Files و برنامه‌های گوناگون Nextcloud به اشتراک بگذارید. برخی برنامه‌ها حتی از ابزارک‌های تعاملی پشتیبانی می‌کنند، برای مثال برنامه Text.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 بگذارید مکالمه‌ها جریان یابند: به کاربران اشاره کنید، به پیام‌ها واکنش نشان دهید و موارد دیگر\n\nمی‌توانید با استفاده از %s به همه افراد مکالمه اشاره کنید، یا با تایپ \"@\" و انتخاب نام آن‌ها از فهرست، به شرکت‌کنندگان مشخصی اشاره کنید.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "می‌توانید به پیام‌ها پاسخ دهید، آنها را به چت‌ها و افراد دیگر ارسال کنید، یا محتوای پیام را کپی کنید.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ با انتخابگر هوشمند کارهای بیشتری انجام دهید\n\nکافی است \"/\" را تایپ کنید یا به منوی \"+\" بروید تا انتخابگر هوشمند باز شود؛ جایی که می‌توانید محتوای گوناگونی را به پیام‌های خود پیوست کنید. می‌توانید انتخابگر هوشمند را طوری پیکربندی کنید که بتواند موارد را از برنامه‌های Nextcloud، GIFها، موقعیت‌های مکانی روی نقشه، محتوای تولیدشده با هوش مصنوعی و موارد دیگر اضافه کند.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ تنظیمات مکالمه را مدیریت کنید\n\nدر منوی مکالمه می‌توانید به تنظیمات گوناگونی برای مدیریت مکالمه‌های خود دسترسی داشته باشید، مانند:\n* ویرایش اطلاعات مکالمه\n* مدیریت اعلان‌ها\n* اعمال قوانین گوناگون نظارتی\n* پیکربندی دسترسی و امنیت\n* فعال کردن ربات‌ها\n* و موارد دیگر!",
    "Andorra" : "آندورا",
    "United Arab Emirates" : "امارات متحده عربی",
    "Afghanistan" : "افغانستان",
    "Antigua and Barbuda" : "آنتیگوا و باربودا",
    "Anguilla" : "آنگویلا",
    "Albania" : "آلبانی",
    "Armenia" : "ارمنستان",
    "Angola" : "آنگولا",
    "Antarctica" : "جنوبگان",
    "Argentina" : "آرژانتین",
    "American Samoa" : "ساموآی آمریکا",
    "Austria" : "اتریش",
    "Australia" : "استرالیا",
    "Aruba" : "آروبا",
    "Åland Islands" : "جزایر الند",
    "Azerbaijan" : "جمهوری آذربایجان",
    "Bosnia and Herzegovina" : "بوسنی و هرزگوین",
    "Barbados" : "باربادوس",
    "Bangladesh" : "بنگلادش",
    "Belgium" : "بلژیک",
    "Burkina Faso" : "بورکینافاسو",
    "Bulgaria" : "بلغارستان",
    "Bahrain" : "بحرین",
    "Burundi" : "بوروندی",
    "Benin" : "بنین",
    "Saint Barthélemy" : "سن‌بارتلمی",
    "Bermuda" : "برمودا",
    "Brunei Darussalam" : "برونئی دارالسلام",
    "Bolivia, Plurinational State of" : "بولیوی، کشور چندملیتی",
    "Bonaire, Sint Eustatius and Saba" : "بونیر، سینت یوستیشس و سابا",
    "Brazil" : "برزیل",
    "Bahamas" : "باهاما",
    "Bhutan" : "بوتان",
    "Bouvet Island" : "جزیره بووه",
    "Botswana" : "بوتسوانا",
    "Belarus" : "بلاروس",
    "Belize" : "بلیز",
    "Canada" : "کانادا",
    "Cocos (Keeling) Islands" : "جزایر کوکوس (کیلینگ)",
    "Congo, the Democratic Republic of the" : "کنگو، جمهوری دموکراتیک",
    "Central African Republic" : "جمهوری آفریقای مرکزی",
    "Congo" : "کنگو",
    "Switzerland" : "سوئیس",
    "Côte d'Ivoire" : "ساحل عاج",
    "Cook Islands" : "جزایر کوک",
    "Chile" : "شیلی",
    "Cameroon" : "کامرون",
    "China" : "چین",
    "Colombia" : "کلمبیا",
    "Costa Rica" : "کاستاریکا",
    "Cuba" : "کوبا",
    "Cabo Verde" : "کیپ ورد",
    "Curaçao" : "کوراسائو",
    "Christmas Island" : "جزیره کریسمس",
    "Cyprus" : "قبرس",
    "Czechia" : "چک",
    "Germany" : "آلمان",
    "Djibouti" : "جیبوتی",
    "Denmark" : "دانمارک",
    "Dominica" : "دومینیکا",
    "Dominican Republic" : "جمهوری دومینیکن",
    "Algeria" : "الجزایر",
    "Ecuador" : "اکوادور",
    "Estonia" : "استونی",
    "Egypt" : "مصر",
    "Western Sahara" : "صحرای غربی",
    "Eritrea" : "اریتره",
    "Spain" : "اسپانیا",
    "Ethiopia" : "اتیوپی",
    "Finland" : "فنلاند",
    "Fiji" : "فیجی",
    "Falkland Islands (Malvinas)" : "جزایر فالکلند (مالویناس)",
    "Micronesia, Federated States of" : "میکرونزی، ایالات فدرال",
    "Faroe Islands" : "جزایر فارو",
    "France" : "فرانسه",
    "Gabon" : "گابن",
    "United Kingdom of Great Britain and Northern Ireland" : "پادشاهی متحد بریتانیای کبیر و ایرلند شمالی",
    "Grenada" : "گرنادا",
    "Georgia" : "گرجستان",
    "French Guiana" : "گویان فرانسه",
    "Guernsey" : "گرنزی",
    "Ghana" : "غنا",
    "Gibraltar" : "جبل‌الطارق",
    "Greenland" : "گرینلند",
    "Gambia" : "گامبیا",
    "Guinea" : "گینه",
    "Guadeloupe" : "گوادلوپ",
    "Equatorial Guinea" : "گینه استوایی",
    "Greece" : "یونان",
    "South Georgia and the South Sandwich Islands" : "جورجیای جنوبی و جزایر ساندویچ جنوبی",
    "Guatemala" : "گواتمالا",
    "Guam" : "گوام",
    "Guinea-Bissau" : "گینه بیسائو",
    "Guyana" : "گویان",
    "Hong Kong" : "هنگ‌کنگ",
    "Heard Island and McDonald Islands" : "جزیره هرد و جزایر مک‌دونالد",
    "Honduras" : "هندوراس",
    "Croatia" : "کرواسی",
    "Haiti" : "هائیتی",
    "Hungary" : "مجارستان",
    "Indonesia" : "اندونزی",
    "Ireland" : "ایرلند",
    "Israel" : "اسرائیل",
    "Isle of Man" : "جزیره من",
    "India" : "هند",
    "British Indian Ocean Territory" : "قلمرو اقیانوس هند بریتانیا",
    "Iraq" : "عراق",
    "Iran, Islamic Republic of" : "ایران، جمهوری اسلامی",
    "Iceland" : "ایسلند",
    "Italy" : "ایتالیا",
    "Jersey" : "جرزی",
    "Jamaica" : "جامائیکا",
    "Jordan" : "اردن",
    "Japan" : "ژاپن",
    "Kenya" : "کنیا",
    "Kyrgyzstan" : "قرقیزستان",
    "Cambodia" : "کامبوج",
    "Kiribati" : "کیریباتی",
    "Comoros" : "کومور",
    "Saint Kitts and Nevis" : "سنت کیتس و نویس",
    "Korea, Democratic People's Republic of" : "کره، جمهوری دموکراتیک خلق",
    "Korea, Republic of" : "کره، جمهوری",
    "Kuwait" : "کویت",
    "Cayman Islands" : "جزایر کیمن",
    "Kazakhstan" : "قزاقستان",
    "Lao People's Democratic Republic" : "جمهوری دموکراتیک خلق لائو",
    "Lebanon" : "لبنان",
    "Saint Lucia" : "سنت لوسیا",
    "Liechtenstein" : "لیختن‌اشتاین",
    "Sri Lanka" : "سری‌لانکا",
    "Liberia" : "لیبریا",
    "Lesotho" : "لسوتو",
    "Lithuania" : "لیتوانی",
    "Luxembourg" : "لوکزامبورگ",
    "Latvia" : "لتونی",
    "Libya" : "لیبی",
    "Morocco" : "مراکش",
    "Monaco" : "موناکو",
    "Moldova, Republic of" : "مولداوی",
    "Montenegro" : "مونته‌نگرو",
    "Saint Martin (French part)" : "سنت مارتین (بخش فرانسوی)",
    "Madagascar" : "ماداگاسکار",
    "Marshall Islands" : "جزایر مارشال",
    "North Macedonia" : "مقدونیه شمالی",
    "Mali" : "مالی",
    "Myanmar" : "میانمار",
    "Mongolia" : "مغولستان",
    "Macao" : "ماکائو",
    "Northern Mariana Islands" : "جزایر ماریانای شمالی",
    "Martinique" : "مارتینیک",
    "Mauritania" : "موریتانی",
    "Montserrat" : "مونتسرات",
    "Malta" : "مالت",
    "Mauritius" : "موریس",
    "Maldives" : "مالدیو",
    "Malawi" : "مالاوی",
    "Mexico" : "مکزیک",
    "Malaysia" : "مالزی",
    "Mozambique" : "موزامبیک",
    "Namibia" : "نامیبیا",
    "New Caledonia" : "کالدونیای جدید",
    "Niger" : "نیجر",
    "Norfolk Island" : "جزیره نورفولک",
    "Nigeria" : "نیجریه",
    "Nicaragua" : "نیکاراگوئه",
    "Netherlands" : "هلند",
    "Norway" : "نروژ",
    "Nepal" : "نپال",
    "Nauru" : "نائورو",
    "Niue" : "نیوئه",
    "New Zealand" : "نیوزیلند",
    "Oman" : "عمان",
    "Panama" : "پاناما",
    "Peru" : "پرو",
    "French Polynesia" : "پلی‌نزی فرانسه",
    "Papua New Guinea" : "پاپوآ گینه نو",
    "Philippines" : "فیلیپین",
    "Pakistan" : "پاکستان",
    "Poland" : "لهستان",
    "Saint Pierre and Miquelon" : "سن پیر و میکلون",
    "Pitcairn" : "پیتکرن",
    "Puerto Rico" : "پورتوریکو",
    "Palestine, State of" : "فلسطین",
    "Portugal" : "پرتغال",
    "Palau" : "پالائو",
    "Paraguay" : "پاراگوئه",
    "Qatar" : "قطر",
    "Réunion" : "رئونیون",
    "Romania" : "رومانی",
    "Serbia" : "صربستان",
    "Russian Federation" : "روسیه",
    "Rwanda" : "رواندا",
    "Saudi Arabia" : "عربستان سعودی",
    "Solomon Islands" : "جزایر سلیمان",
    "Seychelles" : "سیشل",
    "Sudan" : "سودان",
    "Sweden" : "سوئد",
    "Singapore" : "سنگاپور",
    "Saint Helena, Ascension and Tristan da Cunha" : "سنت هلنا، اسنشن و تریستان دا کونا",
    "Slovenia" : "اسلوونی",
    "Svalbard and Jan Mayen" : "سوالبارد و یان ماین",
    "Slovakia" : "اسلواکی",
    "Sierra Leone" : "سیرالئون",
    "San Marino" : "سن مارینو",
    "Senegal" : "سنگال",
    "Somalia" : "سومالی",
    "Suriname" : "سورینام",
    "South Sudan" : "سودان جنوبی",
    "Sao Tome and Principe" : "سائوتومه و پرینسیپ",
    "El Salvador" : "السالوادور",
    "Sint Maarten (Dutch part)" : "سینت مارتن (بخش هلندی)",
    "Syrian Arab Republic" : "سوریه",
    "Eswatini" : "اسواتینی",
    "Turks and Caicos Islands" : "جزایر تورکس و کایکوس",
    "Chad" : "چاد",
    "French Southern Territories" : "سرزمین‌های جنوبی فرانسه",
    "Togo" : "توگو",
    "Thailand" : "تایلند",
    "Tajikistan" : "تاجیکستان",
    "Tokelau" : "توکلائو",
    "Timor-Leste" : "تیمور-لسته",
    "Turkmenistan" : "ترکمنستان",
    "Tunisia" : "تونس",
    "Tonga" : "تونگا",
    "Turkey" : "ترکیه",
    "Trinidad and Tobago" : "ترینیداد و توباگو",
    "Tuvalu" : "تووالو",
    "Taiwan, Province of China" : "تایوان، استان چین",
    "Tanzania, United Republic of" : "تانزانیا، جمهوری متحد",
    "Ukraine" : "اوکراین",
    "Uganda" : "اوگاندا",
    "United States Minor Outlying Islands" : "جزایر کوچک حاشیه‌ای ایالات متحده",
    "United States of America" : "ایالات متحده آمریکا",
    "Uruguay" : "اروگوئه",
    "Uzbekistan" : "ازبکستان",
    "Holy See" : "سریر مقدس",
    "Saint Vincent and the Grenadines" : "سنت وینسنت و گرنادین‌ها",
    "Venezuela, Bolivarian Republic of" : "ونزوئلا، جمهوری بولیواری",
    "Virgin Islands, British" : "جزایر ویرجین بریتانیا",
    "Virgin Islands, U.S." : "جزایر ویرجین ایالات متحده",
    "Viet Nam" : "ویتنام",
    "Vanuatu" : "وانواتو",
    "Wallis and Futuna" : "والیس و فوتونا",
    "Samoa" : "ساموآ",
    "Yemen" : "یمن",
    "Mayotte" : "مایوت",
    "South Africa" : "آفریقای جنوبی",
    "Zambia" : "زامبیا",
    "Zimbabwe" : "زیمبابوه",
    "Background blur" : "محو کردن پس‌زمینه",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "امکان بررسی پشتیبانی از بارگذاری WASM وجود ندارد. لطفاً به‌صورت دستی بررسی کنید که سرور وب شما فایل‌های `.wasm` را ارائه می‌دهد.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "سرور وب شما به‌درستی برای ارائه فایل‌های `.wasm` پیکربندی نشده است. این معمولاً یک مشکل در تنظیمات Nginx است. برای محو کردن پس‌زمینه، نیاز به تنظیماتی برای ارائه فایل‌های `.wasm` دارید. تنظیمات Nginx خود را با پیکربندی توصیه‌شده در مستندات ما مقایسه کنید.",
    "Talk configuration values" : "مقادیر پیکربندی Talk",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "اعمال مدت زمان اجباری برای تماس فقط با cron سیستمی پشتیبانی می‌شود. لطفاً cron سیستمی را فعال کنید یا پیکربندی `max_call_duration` را حذف کنید.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "مقادیر کوچک `max_call_duration` (در حال حاضر روی %d تنظیم شده است) به دلیل محدودیت‌های فنی قابل اعمال نیستند. کار پس‌زمینه فقط هر ۵ دقیقه یکبار اجرا می‌شود، بنابراین با مسئولیت خود استفاده کنید.",
    "Federation" : "فدراسیون",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "هنگامی که Talk Federation فعال است، توصیه می‌شود \"memcache.locking\" را پیکربندی کنید.",
    "High-performance backend" : "بک‌اند با کارایی بالا",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "هیچ بک‌اند با کارایی بالا پیکربندی نشده است - اجرای نکست‌کلود Talk بدون بک‌اند با کارایی بالا فقط برای تماس‌های بسیار کوچک (حداکثر ۲-۳ شرکت‌کننده) مقیاس‌پذیر است. لطفاً بک‌اند با کارایی بالا را تنظیم کنید تا تماس‌های با چندین شرکت‌کننده به‌خوبی کار کنند.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "اجرای حالت \"conversation_cluster\" بک‌اند با کارایی بالا منسوخ شده است و در نسخه آینده پشتیبانی نخواهد شد. بک‌اند با کارایی بالا امروزه از خوشه‌بندی واقعی پشتیبانی می‌کند که باید به جای آن استفاده شود.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "تعریف چندین بک‌اند با کارایی بالا منسوخ شده است و در نسخه آینده پشتیبانی نخواهد شد. در عوض، باید یک متعادل‌کننده بار همراه با سرورهای سیگنالینگ خوشه‌ای تنظیم و در تنظیمات Talk پیکربندی شود.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "کلید عمومی ذخیره‌شده برای الگوریتم استفاده‌شده %1$s با کلید خصوصی ذخیره‌شده مطابقت ندارد. برای رفع مشکل، %2$s را اجرا کنید.",
    "High-performance backend not configured correctly. Run %s for details." : "بک‌اند با کارایی بالا به‌درستی پیکربندی نشده است. برای جزئیات، %s را اجرا کنید.",
    "High-performance backend not configured correctly" : "بک‌اند با کارایی بالا به‌درستی پیکربندی نشده است",
    "Error: Cannot connect to server" : "خطا: اتصال به سرور امکان‌پذیر نیست",
    "Error: Server did not respond with proper JSON" : "خطا: سرور با JSON مناسب پاسخ نداد",
    "Error: Certificate expired" : "خطا: گواهی منقضی شده است",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "خطا: زمان سیستم سرور نکست‌کلود و سرور بک‌اند با کارایی بالا هماهنگ نیستند. لطفاً مطمئن شوید که هر دو سرور به یک سرور زمان متصل هستند یا زمان آن‌ها را به‌صورت دستی هماهنگ کنید.",
    "Could not get version" : "دریافت نسخه امکان‌پذیر نیست",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "خطا: نسخه در حال اجرا: {version}؛ سرور باید به‌روزرسانی شود تا با این نسخه از Talk سازگار باشد",
    "Error: Server responded with: {error}" : "خطا: سرور پاسخ داد: {error}",
    "Error: Unknown error occurred" : "خطا: خطای ناشناخته رخ داد",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "هشدار: نسخه در حال اجرا: {version}؛ سرور از همه ویژگی‌های این نسخه Talk پشتیبانی نمی‌کند، ویژگی‌های از دست رفته: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "هنگام اجرای نکست‌کلود Talk با بک‌اند با کارایی بالا، توصیه می‌شود یک حافظه نهان (memory cache) پیکربندی کنید.",
    "Client Push" : "Client Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Client Push نصب شده است، این کار به‌موقع بودن اعلان‌های Talk را بهبود می‌بخشد.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} نصب نشده است. این ممکن است باعث تأخیر در اعلان‌های Talk شود.",
    "Recording backend" : "بک‌اند ضبط",
    "Using the recording backend requires a High-performance backend." : "استفاده از بک‌اند ضبط نیاز به بک‌اند با کارایی بالا دارد.",
    "No recording backend configured" : "هیچ بک‌اند ضبطی پیکربندی نشده است",
    "SIP configuration" : "تنظیمات SIP",
    "Using the SIP functionality requires a High-performance backend." : "استفاده از قابلیت SIP نیاز به بک‌اند با کارایی بالا دارد.",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "شماره‌های تلفن Talk اختصاص‌یافته نباید با + یا 0 شروع شوند. لطفاً شماره‌های زیر را حذف یا به‌روزرسانی کنید:",
    "No SIP backend configured" : "هیچ بک‌اند SIP پیکربندی نشده است",
    "Invalid date, date format must be YYYY-MM-DD" : "تاریخ نامعتبر است، فرمت تاریخ باید YYYY-MM-DD باشد",
    "Conversation not found" : "گفتگو یافت نشد",
    "Path is already shared with this conversation" : "مسیر قبلاً با این گفتگو به اشتراک گذاشته شده است",
    "Chat, video & audio-conferencing using WebRTC" : "چت، ویدئو و کنفرانس صوتی با استفاده از WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "گفتگوی متنی، تصویری و صوتی با استفاده از WebRTC\n\n* 💬 **گفتگو** Nextcloud Talk یک گفتگوی متنی ساده دارد که به شما امکان می‌دهد فایل‌ها را از برنامهٔ Files نکست‌کلود یا دستگاه محلی خود به اشتراک بگذارید یا بارگذاری کنید و از سایر شرکت‌کنندگان نام ببرید.\n* 👥 **تماس‌های خصوصی، گروهی، عمومی و محافظت‌شده با گذرواژه!** کسی را دعوت کنید، یک گروه کامل را فرابخوانید یا برای دعوت به تماس یک پیوند عمومی بفرستید.\n* 🌐 **گفتگوهای فدرال** با سایر کاربران Nextcloud روی سرورهای خودشان گفتگو کنید\n* 💻 **اشتراک‌گذاری صفحه!** صفحهٔ خود را با شرکت‌کنندگان تماس به اشتراک بگذارید.\n* 🚀 **یکپارچگی با سایر برنامه‌های Nextcloud** مانند Files، Calendar، User status، Dashboard، Flow، Maps، Smart picker، Contacts، کارتابلو بسیاری دیگر.\n* 🌉 **همگام‌سازی با سایر راهکارهای گفتگو** با یکپارچه‌شدن [Matterbridge](https://github.com/42wim/matterbridge/) در Talk، می‌توانید بسیاری از راهکارهای گفتگوی دیگر را به‌آسانی با Nextcloud Talk همگام کنید و بالعکس.",
    "Leave call" : "خروج از تماس",
    "Navigating away from the page will leave the call in {conversation}" : "خروج از صفحه باعث خروج از تماس در {conversation} می‌شود",
    "Stay in call" : "ماندن در تماس",
    "Error occurred when getting the conversation information" : "هنگام دریافت اطلاعات گفتگو خطایی رخ داد",
    "Duplicate session" : "نشست تکراری",
    "Discuss this file" : "بحث درباره این فایل",
    "Loading …" : "در حال بارگذاری...",
    "Share this file with others to discuss it" : "این فایل را با دیگران به اشتراک بگذارید تا درباره آن بحث کنید",
    "Join conversation" : "پیوستن به گفتگو",
    "Share this file" : "اشتراک‌گذاری این فایل",
    "Error occurred when joining the conversation" : "هنگام پیوستن به گفتگو خطایی رخ داد",
    "Open in full application" : "باز کردن در برنامه کامل",
    "This conversation is password-protected." : "این گفتگو با رمز عبور محافظت می‌شود.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "ما چندین تلاش ناموفق برای رمز عبور از IP شما شناسایی کرده‌ایم. بنابراین تلاش بعدی شما تا 30 ثانیه محدود می‌شود.",
    "The password is wrong. Try again." : "رمز عبور اشتباه است. دوباره تلاش کنید.",
    "Password" : "رمز عبور",
    "Submit" : "ارسال",
    "Error requesting the password." : "خطا در درخواست رمز عبور.",
    "Request password" : "درخواست رمز عبور",
    "This conversation has ended" : "این گفتگو به پایان رسیده است",
    "Close Talk sidebar" : "بستن نوار کناری Talk",
    "Open Talk sidebar" : "باز کردن نوار کناری Talk",
    "Everyone" : "همه",
    "Users and moderators" : "کاربران و مدیران",
    "Moderators only" : "فقط مدیران",
    "Disable calls" : "غیرفعال کردن تماس‌ها",
    "Save changes" : "ذخیره تغییرات",
    "Saving …" : "ذخیره کردن …",
    "Saved!" : "ذخیره شد!",
    "Limit to groups" : "محدودیت به گروه‌ها",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "هنگامی که حداقل یک گروه انتخاب شده است، فقط افراد گروه‌های لیست شده می‌توانند بخشی از گفتگوها باشند.",
    "Guests can still join public conversations." : "مهمانان همچنان می‌توانند به گفتگوهای عمومی بپیوندند.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "کاربرانی که دیگر نمی‌توانند از Talk استفاده کنند، همچنان به عنوان شرکت‌کننده در گفتگوهای قبلی خود لیست می‌شوند و پیام‌های چت آنها نیز حفظ می‌شود.",
    "Limit using Talk" : "محدود کردن استفاده از Talk",
    "Limit creating a public and group conversation" : "محدود کردن ایجاد گفتگوی عمومی و گروهی",
    "Limit creating conversations" : "محدود کردن ایجاد گفتگو",
    "Limit starting a call" : "محدود کردن شروع تماس",
    "Limit starting calls" : "محدودیت شروع تماس‌ها",
    "When a call has started, everyone with access to the conversation can join the call." : "وقتی تماسی شروع شد، هرکسی که به گفتگو دسترسی دارد می‌تواند به تماس بپیوندد.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "ربات‌های زیر روی این سرور نصب شده‌اند. در مستندات می‌توانید جزئیات {linkstart1}ساخت ربات خود{linkend} یا {linkstart2}فهرست ربات‌ها{linkend} را برای فعال‌سازی روی سرور خود بیابید.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "هیچ رباتی روی این سرور نصب نشده است. در مستندات می‌توانید جزئیات {linkstart1}ساخت ربات خود{linkend} یا {linkstart2}فهرست ربات‌ها{linkend} را برای فعال‌سازی روی سرور خود بیابید.",
    "Description is not provided" : "توضیحاتی ارائه نشده است",
    "Locked for moderators" : "قفل شده برای مدیران",
    "Enabled" : "فعال",
    "Disabled" : "غیرفعال",
    "Bots settings" : "تنظیمات ربات‌ها",
    "State" : "وضعیت",
    "Name" : "نام",
    "Last error" : "آخرین خطا",
    "Total errors count" : "تعداد کل خطاها",
    "Find more bots" : "یافتن ربات‌های بیشتر",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "سرورهای مورد اعتماد را می‌توانید در {linkstart}صفحه تنظیمات اشتراک‌گذاری{linkend} پیکربندی کنید.",
    "Beta" : "بتا",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "چت‌ها و تماس‌های فدرال شده هم‌اکنون کار می‌کنند. مدیریت پیوست‌ها در نسخه آینده اضافه خواهد شد.",
    "Enable Federation in Talk app" : "فعال‌سازی فدراسیون در برنامه Talk",
    "Permissions" : "مجوزها",
    "Allow users to be invited to federated conversations" : "اجازه دعوت کاربران به گفتگوهای فدرال شده",
    "Allow users to invite federated users into conversation" : "اجازه دعوت کاربران فدرال شده به گفتگوها",
    "Only allow to federate with trusted servers" : "فقط اجازه فدرال شدن با سرورهای مورد اعتماد",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "وقتی حداقل یک گروه انتخاب شده باشد، فقط افراد گروه‌های لیست شده می‌توانند کاربران فدرال شده را به گفتگوها دعوت کنند.",
    "Groups allowed to invite federated users" : "گروه‌های مجاز به دعوت کاربران فدرال شده",
    "Select groups …" : "انتخاب گروه‌ها …",
    "All messages" : "همه پیام‌ها",
    "@-mentions only" : "فقط اشاره‌های @",
    "Off" : "خاموش",
    "General settings" : "تنظیمات عمومی",
    "Default notification settings" : "تنظیمات پیش‌فرض اعلان‌ها",
    "Default group notification" : "اعلان پیش‌فرض گروه",
    "Default group notification for new groups" : "اعلان پیش‌فرض گروه برای گروه‌های جدید",
    "Integration into other apps" : "ادغام در سایر برنامه‌ها",
    "Allow conversations on files" : "اجازه گفتگو روی فایل‌ها",
    "Allow conversations on public shares for files" : "اجازه گفتگو روی اشتراک‌های عمومی برای فایل‌ها",
    "End-to-end encrypted calls" : "تماس‌های رمزگذاری شده سرتاسر",
    "Enable encryption" : "فعال‌سازی رمزگذاری",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "تماس‌های رمزگذاری شده سرتاسر با پل SIP پیکربندی شده نیاز به نسخه جدیدتری از بک‌اند با کارایی بالا و پل SIP دارند.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "کلاینت‌های موبایل در حال حاضر از تماس‌های رمزگذاری شده سرتاسر پشتیبانی نمی‌کنند.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "با کلیک روی دکمه بالا، اطلاعات فرم به سرورهای Struktur AG ارسال می‌شود. اطلاعات بیشتر را می‌توانید در {linkstart}spreed.eu{linkend} بیابید.",
    "Pending" : "در انتظار",
    "Error" : "خطا",
    "Blocked" : "مسدود شده",
    "Active" : "فعال",
    "Expired" : "منقضی شده",
    "Never" : "هرگز",
    "The trial could not be requested. Please try again later." : "امکان درخواست نسخه آزمایشی وجود نداشت. لطفاً بعداً دوباره تلاش کنید.",
    "The account could not be deleted. Please try again later." : "امکان حذف حساب وجود نداشت. لطفاً بعداً دوباره تلاش کنید.",
    "Hosted High-performance backend" : "بک‌اند میزبانی با کارایی بالا",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "شریک ما Struktur AG سرویسی ارائه می‌دهد که می‌توان یک سرور سیگنالینگ میزبانی شده درخواست کرد. برای این کار فقط باید فرم زیر را پر کنید و نکست‌کلود شما آن را درخواست می‌کند. پس از راه‌اندازی سرور برای شما، اعتبارنامه‌ها به طور خودکار پر می‌شوند. این کار تنظیمات موجود سرور سیگنالینگ را بازنویسی می‌کند.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "اگر حساب بک‌اند پرفورمنس بالا شامل قابلیت STUN و/یا TURN باشد، تنظیمات به‌روزرسانی می‌شوند.",
    "URL of this Nextcloud instance" : "URL این نمونه نکست‌کلود",
    "Full name of the user requesting the trial" : "نام کامل کاربر درخواست‌دهنده نسخه آزمایشی",
    "Email of the user" : "ایمیل کاربر",
    "Language" : "زبان",
    "Country" : "کشور",
    "Request signaling server trial" : "درخواست نسخه آزمایشی سرور سیگنالینگ",
    "You can see the current status of your hosted signaling server in the following table." : "وضعیت فعلی سرور سیگنالینگ میزبانی‌شده خود را در جدول زیر مشاهده می‌کنید.",
    "Status" : "وضعیت",
    "Created at" : "ایجاد شده در",
    "Expires at" : "منقضی می‌شود در",
    "Limits" : "محدودیت‌ها",
    "STUN included" : "STUN شامل شده",
    "Yes" : "بله",
    "No" : "خیر",
    "TURN included" : "TURN شامل شده",
    "Delete the signaling server account" : "حذف حساب سرور سیگنالینگ",
    "_%n user_::_%n users_" : ["%n user","%n users"],
    "Installed version: {version}" : "نسخه نصب‌شده: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "می‌توانید Matterbridge را برای اتصال نکست‌کلود تاک به برخی سرویس‌های دیگر نصب کنید. برای جزئیات بیشتر به {linkstart1}صفحه گیت‌هاب{linkend} آن مراجعه کنید. دانلود و نصب برنامه ممکن است مدتی طول بکشد. در صورت تایم اوت، لطفاً آن را به صورت دستی از {linkstart2}فروشگاه برنامه نکست‌کلود{linkend} نصب کنید.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "دسترسی‌های فایل اجرایی Matterbridge نادرست است. لطفاً مطمئن شوید که فایل اجرایی Matterbridge متعلق به کاربر صحیح است و قابل اجرا می‌باشد. این فایل را می‌توانید در \"/…/nextcloud/apps/talk_matterbridge/bin/\" پیدا کنید.",
    "Matterbridge binary was not found or couldn't be executed." : "باینری Matterbridge پیدا نشد یا قابلیت اجرا نداشت.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "همچنین می‌توانید مسیر باینری Matterbridge را به صورت دستی از طریق کانفیگ تنظیم کنید. برای اطلاعات بیشتر به {linkstart}مستندات یکپارچه‌سازی Matterbridge{linkend} مراجعه کنید.",
    "Downloading …" : "در حال بارگیری …",
    "Install Talk Matterbridge" : "نصب Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "هنگام نصب برنامه Matterbridge خطایی رخ داد",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "هنگام نصب Talk Matterbridge خطایی رخ داد. لطفاً آن را به صورت دستی نصب کنید",
    "Failed to execute Matterbridge binary." : "اجرای باینری Matterbridge ناموفق بود.",
    "Matterbridge integration" : "یکپارچه‌سازی Matterbridge",
    "Enable Matterbridge integration" : "فعال‌سازی یکپارچه‌سازی Matterbridge",
    "Status: Checking connection" : "وضعیت: در حال بررسی اتصال",
    "OK: Running version: {version}" : "OK: نسخه در حال اجرا: {version}",
    "Error: Server seems to be a Signaling server" : "خطا: سرور به نظر می‌رسد یک سرور سیگنالینگ است",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "خطا: زمان سیستم سرور نکست‌کلود و سرور بک‌اند ضبط هماهنگ نیستند. لطفاً مطمئن شوید که هر دو سرور به یک سرور زمان متصل هستند یا زمان آن‌ها را به صورت دستی هماهنگ کنید.",
    "Recording backend URL" : "URL بک‌اند ضبط",
    "Validate SSL certificate" : "اعتبارسنجی گواهی SSL",
    "Delete this server" : "حذف این سرور",
    "Test this server" : "آزمایش این سرور",
    "Disabled for all calls" : "غیرفعال برای همه تماس‌ها",
    "Enabled for all calls" : "فعال برای همه تماس‌ها",
    "Configurable on conversation level by moderators" : "قابل تنظیم در سطح مکالمه توسط مدیران",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "تنظیمات PHP \"upload_max_filesize\" یا \"post_max_size\" فقط امکان آپلود فایل‌ها تا {maxUpload} را می‌دهد.",
    "Recording backend settings saved" : "تنظیمات بک‌اند ضبط ذخیره شد",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "به مدیران اجازه داده می‌شود رضایت را در سطح مکالمه فعال کنند. رضایت برای ضبط شدن برای هر شرکت‌کننده قبل از پیوستن به هر تماس در این مکالمه الزامی خواهد بود.",
    "The consent to be recorded will be required for each participant before joining every call." : "رضایت برای ضبط شدن برای هر شرکت‌کننده قبل از پیوستن به هر تماس الزامی خواهد بود.",
    "The consent to be recorded is not required." : "رضایت برای ضبط شدن الزامی نیست.",
    "Recording backend configuration is only possible with a High-performance backend." : "پیکربندی بک‌اند ضبط فقط با یک بک‌اند پرفورمنس بالا امکان‌پذیر است.",
    "Add a new recording backend server" : "افزودن سرور بک‌اند ضبط جدید",
    "Shared secret" : "رمز اشتراک‌گذاری‌شده",
    "Recording consent" : "رضایت برای ضبط",
    "Recording transcription" : "رونوشت ضبط",
    "Automatically transcribe call recordings with a transcription provider" : "ضبط خودکار تماس‌ها با یک ارائه‌دهنده رونوشت",
    "Automatically summarize call recordings with transcription and summary providers" : "خلاصه‌سازی خودکار ضبط تماس‌ها با ارائه‌دهندگان رونوشت و خلاصه",
    "SIP configuration saved!" : "تنظیمات SIP ذخیره شد!",
    "SIP configuration is only possible with a High-performance backend." : "تنظیمات SIP فقط با بک‌اند با کارایی بالا امکان‌پذیر است.",
    "Enable SIP Dial-out option" : "فعال‌سازی گزینه تماس خروجی SIP",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "سرور سیگنال‌دهی باید برای پشتیبانی از ویژگی تماس خروجی SIP به‌روزرسانی شود.",
    "Do not show SIP Dial-out caller number" : "نمایش ندادن شماره تماس‌گیرنده تماس خروجی SIP",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "شماره ناشناس باید برای گیرنده تماس به صورت «ناشناس» یا «شماره مخفی» نمایش داده شود.",
    "Dial-out number" : "شماره تماس خروجی",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "شماره فرمت‌شده E164 به عنوان شماره تماس‌گیرنده پیش‌فرض برای تماس‌های خروجی استفاده می‌شود",
    "Dial-out prefix" : "پیشوند تماس خروجی",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "پیشوند به شماره کاربر پیکربندی‌شده برای تماس‌های خروجی (پیش‌فرض `+` است)",
    "Restrict SIP configuration" : "محدود کردن تنظیمات SIP",
    "Enable SIP configuration" : "فعال‌سازی تنظیمات SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "فقط کاربران گروه‌های زیر می‌توانند SIP را در مکالماتی که مدیریت می‌کنند فعال کنند",
    "Phone number (Country)" : "شماره تلفن (کشور)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "این اطلاعات در ایمیل‌های دعوت ارسال می‌شود و همچنین در نوار کناری به همه شرکت‌کنندگان نمایش داده می‌شود.",
    "Nextcloud base URL" : "آدرس پایه نکست‌کلود",
    "Talk Backend URL" : "آدرس بک‌اند تاک",
    "WebSocket URL" : "آدرس وب‌سوکت",
    "Available features" : "ویژگی‌های موجود",
    "Error: Websocket connection failed" : "خطا: اتصال وب‌سوکت ناموفق بود",
    "Error code" : "کد خطا",
    "Error message" : "پیام خطا",
    "Error: Websocket connection failed. Check browser console" : "خطا: اتصال وب‌سوکت ناموفق بود. کنسول مرورگر را بررسی کنید",
    "High-performance backend URL" : "آدرس بک‌اند با کارایی بالا",
    "Missing High-performance backend warning hidden" : "هشدار بک‌اند با کارایی بالا پنهان شد",
    "High-performance backend settings saved" : "تنظیمات بک‌اند با کارایی بالا ذخیره شد",
    "Nextcloud Talk setup not complete" : "راه‌اندازی نکست‌کلود تاک کامل نشده است",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "لطفاً توجه داشته باشید که در تماس‌های با بیش از ۲ شرکت‌کننده بدون بک‌اند با کارایی بالا، شرکت‌کنندگان احتمالاً با مشکلات اتصال مواجه می‌شوند و بار زیادی روی دستگاه‌های شرکت‌کننده ایجاد می‌شود.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "بک‌اند با کارایی بالا را نصب کنید تا تماس‌های با چند شرکت‌کننده به خوبی کار کنند.",
    "Nextcloud portal" : "پورتال نکست‌کلود",
    "Quick installation guide" : "راهنمای نصب سریع",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "بک‌اند با کارایی بالا برای تماس‌ها و مکالمات با چند شرکت‌کننده ضروری است. بدون این بک‌اند، همه شرکت‌کنندگان باید ویدیوی خود را به صورت جداگانه برای هر شرکت‌کننده دیگر آپلود کنند که احتمالاً باعث مشکلات اتصال و بار زیاد روی دستگاه‌های شرکت‌کننده می‌شود.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "توصیه می‌شود هنگام استفاده از نکست‌کلود تاک با بک‌اند با کارایی بالا، یک کش توزیع‌شده راه‌اندازی کنید.",
    "Add High-performance backend server" : "افزودن سرور بک‌اند با کارایی بالا",
    "Warn about connectivity issues in calls with more than 2 participants" : "هشدار در مورد مشکلات اتصال در تماس‌های با بیش از ۲ شرکت‌کننده",
    "STUN server URL" : "آدرس سرور STUN",
    "The server address is invalid" : "آدرس سرور نامعتبر است",
    "STUN settings saved" : "تنظیمات STUN ذخیره شد",
    "STUN servers" : "سرورهای STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "از سرور STUN برای تعیین آدرس IP عمومی شرکت‌کنندگان پشت روتر استفاده می‌شود.",
    "Add a new STUN server" : "افزودن سرور STUN جدید",
    "{schema} scheme must be used with a domain" : "طرح {schema} باید با یک دامنه استفاده شود",
    "{option1} and {option2}" : "{option1} و {option2}",
    "{option} only" : "فقط {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: کاندیدهای ICE موفق توسط سرور TURN بازگردانده شدند",
    "Error: No working ICE candidates returned by the TURN server" : "خطا: هیچ کاندید ICE کاری توسط سرور TURN بازگردانده نشد",
    "Testing whether the TURN server returns ICE candidates" : "آزمایش اینکه آیا سرور TURN کاندیدهای ICE را بازمی‌گرداند",
    "TURN server schemes" : "طرح‌های سرور TURN",
    "TURN server URL" : "آدرس URL سرور TURN",
    "TURN server secret" : "رمز سرور TURN",
    "TURN server protocols" : "پروتکل‌های سرور TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "از سرور TURN برای پروکسی کردن ترافیک شرکت‌کنندگانی که پشت فایروال هستند استفاده می‌شود. اگر شرکت‌کنندگان نتوانند به دیگران متصل شوند، احتمالاً به یک سرور TURN نیاز است. برای راهنمایی راه‌اندازی به {linkstart}این مستندات{linkend} مراجعه کنید.",
    "TURN settings saved" : "تنظیمات TURN ذخیره شد",
    "TURN servers" : "سرورهای TURN",
    "Add a new TURN server" : "افزودن سرور TURN جدید",
    "Failed" : "ناموفق",
    "OK" : "تأیید",
    "Checking …" : "در حال بررسی …",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "ناموفق: WebAssembly در این مرورگر غیرفعال یا پشتیبانی نمی‌شود. لطفاً WebAssembly را فعال کنید یا از مرورگری استفاده کنید که از آن پشتیبانی می‌کند تا بررسی انجام شود.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "ناموفق: فایل‌های \".wasm\" و \".tflite\" به درستی توسط وب‌سرور بازگردانده نشدند. لطفاً بخش \"نیازمندی‌های سیستم\" را در مستندات Talk بررسی کنید.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "تأیید: فایل‌های \".wasm\" و \".tflite\" به درستی توسط وب‌سرور بازگردانده شدند.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "به نظر می‌رسد تنظیمات PHP و Apache سازگار نیستند. لطفاً توجه داشته باشید که PHP فقط با ماژول MPM_PREFORK و PHP-FPM فقط با ماژول MPM_EVENT قابل استفاده است.",
    "Web server setup checks" : "بررسی‌های راه‌اندازی وب‌سرور",
    "Files required for virtual background can be loaded" : "فایل‌های مورد نیاز برای پس‌زمینه مجازی قابل بارگیری هستند",
    "Federated user" : "کاربر فدرال",
    "Assign participants to rooms" : "اختصاص شرکت‌کنندگان به اتاق‌ها",
    "Configure breakout rooms" : "پیکربندی اتاق‌های گروهی",
    "Number of breakout rooms" : "تعداد اتاق‌های گروهی",
    "You can create from 1 to 20 breakout rooms." : "می‌توانید از ۱ تا ۲۰ اتاق گروهی ایجاد کنید.",
    "Assignment method" : "روش تخصیص",
    "Automatically assign participants" : "تخصیص خودکار شرکت‌کنندگان",
    "Manually assign participants" : "تخصیص دستی شرکت‌کنندگان",
    "Allow participants to choose" : "اجازه انتخاب به شرکت‌کنندگان",
    "Create rooms" : "ایجاد اتاق‌ها",
    "Confirm" : "تأیید",
    "Create breakout rooms" : "ایجاد اتاق‌های گروهی",
    "Reset" : "بازنشانی",
    "Delete breakout rooms" : "حذف اتاق‌های گروهی",
    "Room {roomNumber}" : "اتاق {roomNumber}",
    "Current breakout rooms and settings will be lost" : "اتاق‌های گروهی و تنظیمات فعلی از دست خواهند رفت",
    "Cancel" : "لغو",
    "Unassigned participants" : "شرکت‌کنندگان تخصیص‌نیافته",
    "Back" : "بازگشت",
    "Assign" : "تخصیص",
    "Add participant \"{user}\"" : "افزودن شرکت‌کننده \"{user}\"",
    "Now" : "اکنون",
    "Invalid calendar selected" : "تقویم نامعتبر انتخاب شد",
    "Invalid start time selected" : "زمان شروع نامعتبر انتخاب شد",
    "Invalid end time selected" : "زمان پایان نامعتبر انتخاب شد",
    "Unknown error occurred" : "خطای ناشناخته رخ داد",
    "Sending no invitations" : "بدون ارسال دعوت‌نامه",
    "{participant0} will receive an invitation" : "{participant0} یک دعوت‌نامه دریافت خواهد کرد",
    "{participant0} and {participant1} will receive invitations" : "{participant0} و {participant1} دعوت‌نامه دریافت خواهند کرد",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} and %n other will receive invitations","{participant0}, {participant1} and %n others will receive invitations"],
    "Invite {user}" : "دعوت از {user}",
    "Invite all users and emails in this conversation" : "دعوت از همه کاربران و ایمیل‌های موجود در این گفتگو",
    "Meeting created" : "جلسه ایجاد شد",
    "Upcoming meetings" : "جلسات پیش‌رو",
    "No upcoming meetings" : "جلسه پیش‌رویی وجود ندارد",
    "Schedule a meeting" : "برنامه‌ریزی جلسه",
    "Meeting title" : "عنوان جلسه",
    "From" : "از",
    "To" : "تا",
    "Calendar" : "تقویم",
    "Attendees" : "شرکت‌کنندگان",
    "No other participants to send invitations to." : "شرکت‌کننده دیگری برای ارسال دعوت‌نامه وجود ندارد.",
    "Add attendees" : "افزودن شرکت‌کنندگان",
    "Save" : "ذخیره",
    "Search participants" : "جستجوی شرکت‌کنندگان",
    "No results" : "نتیجه‌ای یافت نشد",
    "Done" : "انجام شد",
    "Disable live transcription" : "غیرفعال کردن رونوشت زنده",
    "Enable live transcription (generated by AI)" : "فعال کردن رونوشت زنده (تولید شده توسط هوش مصنوعی)",
    "Enable live transcription (Live transcriptions app is not installed)" : "فعال کردن رونوشت زنده (برنامه رونوشت زنده نصب نشده است)",
    "Disable live translation" : "غیرفعال کردن ترجمه زنده",
    "Enable live translation (generated by AI)" : "فعال کردن ترجمه زنده (تولید شده توسط هوش مصنوعی)",
    "Original language" : "زبان اصلی",
    "Live translations app is not installed" : "برنامه ترجمه زنده نصب نشده است",
    "Original language: {languageName}" : "زبان اصلی: {languageName}",
    "Translated language" : "زبان ترجمه شده",
    "Translated language: {languageName}" : "زبان ترجمه شده: {languageName}",
    "Exit full screen (F)" : "خروج از تمام صفحه (F)",
    "Full screen (F)" : "تمام صفحه (F)",
    "Speaker view" : "نمای سخنران",
    "Grid view" : "نمای شبکه",
    "Error when trying to load the available live transcription languages" : "خطا در بارگذاری زبان‌های رونوشت زنده موجود",
    "Failed to enable live transcription" : "فعال‌سازی رونوشت زنده با شکست مواجه شد",
    "Failed to enable live translations" : "فعال‌سازی ترجمه زنده با شکست مواجه شد",
    "Failed to disable live translations" : "غیرفعال‌سازی ترجمه زنده با شکست مواجه شد",
    "Recording consent is required" : "رضایت برای ضبط الزامی است",
    "This conversation is read-only" : "این گفتگو فقط خواندنی است",
    "Conversation not found or not joined" : "گفتگو یافت نشد یا به آن ملحق نشده‌اید",
    "Lobby is still active and you're not a moderator" : "لابی هنوز فعال است و شما مدیر جلسه نیستید",
    "Connection failed" : "اتصال برقرار نشد",
    "Reload" : "بارگذاری مجدد",
    "{nickName} raised their hand." : "{nickName} دست خود را بالا برد.",
    "A participant raised their hand." : "یک شرکت‌کننده دست خود را بالا برد.",
    "Collapse stripe" : "جمع کردن نوار",
    "Expand stripe" : "باز کردن نوار",
    "Previous page of videos" : "صفحه قبلی ویدیوها",
    "Next page of videos" : "صفحه بعدی ویدیوها",
    "Connecting …" : "در حال اتصال …",
    "Calling …" : "در حال برقراری تماس …",
    "Waiting for {user} to join the call" : "در انتظار پیوستن {user} به تماس",
    "Waiting for others to join the call …" : "در انتظار پیوستن دیگران به تماس …",
    "You can invite others in the participant tab of the sidebar" : "می‌توانید دیگران را در برگه شرکت‌کنندگان نوار کناری دعوت کنید",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "می‌توانید دیگران را در برگه شرکت‌کنندگان نوار کناری دعوت کنید یا این پیوند را برای دعوت دیگران به اشتراک بگذارید!",
    "Share this link to invite others!" : "این لینک را برای دعوت دیگران به اشتراک بگذارید!",
    "Copy link" : "کپی لینک",
    "You are not allowed to enable audio" : "شما مجاز به فعال‌سازی صدا نیستید",
    "No audio. Click to select device" : "صدایی نیست. برای انتخاب دستگاه کلیک کنید",
    "Mute audio" : "قطع صدا",
    "Mute audio (M)" : "قطع صدا (M)",
    "Unmute audio" : "فعال‌سازی صدا",
    "Unmute audio (M)" : "فعال‌سازی صدا (M)",
    "None" : "هیچکدام",
    "Select a microphone" : "یک میکروفون انتخاب کنید",
    "Select a speaker" : "یک بلندگو انتخاب کنید",
    "Microphone settings" : "تنظیمات میکروفون",
    "Check devices" : "بررسی دستگاه‌ها",
    "Access to camera was denied" : "دسترسی به دوربین رد شد",
    "Error while accessing camera: It is likely in use by another program" : "خطا در دسترسی به دوربین: احتمالاً توسط برنامه دیگری استفاده می‌شود",
    "Error while accessing camera" : "خطا در دسترسی به دوربین",
    "You have been muted by a moderator" : "صدای شما توسط یک مدیر قطع شده است",
    "Hide presenter video" : "مخفی کردن ویدیوی ارائه‌دهنده",
    "You are not allowed to enable video" : "شما مجاز به فعال‌سازی ویدیو نیستید",
    "No video. Click to select device" : "ویدیویی نیست. برای انتخاب دستگاه کلیک کنید",
    "Disable video" : "غیرفعال کردن ویدیو",
    "Disable video (V)" : "غیرفعال کردن ویدیو (V)",
    "Enable video" : "فعال‌سازی ویدیو",
    "Enable video (V)" : "فعال‌سازی ویدیو (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "فعال‌سازی ویدیو - اتصال شما هنگام فعال‌سازی ویدیو برای اولین بار به طور موقت قطع می‌شود",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "فعال‌سازی ویدیو (V) - اتصال شما هنگام فعال‌سازی ویدیو برای اولین بار به طور موقت قطع می‌شود",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "فعال‌سازی ویدیو. اتصال شما هنگام فعال‌سازی ویدیو برای اولین بار به طور موقت قطع می‌شود",
    "Select a video device" : "یک دستگاه ویدیو انتخاب کنید",
    "Show presenter" : "نمایش ارائه‌دهنده",
    "You" : "شما",
    "Mute" : "قطع صدا",
    "Muted" : "صدا قطع است",
    "Show screen" : "نمایش صفحه",
    "Stop following" : "توقف دنبال کردن",
    "Connection could not be established …" : "برقراری ارتباط ممکن نشد …",
    "Connection was lost and could not be re-established …" : "ارتباط قطع شد و برقراری دوباره آن ممکن نشد …",
    "Connection could not be established. Trying again …" : "برقراری ارتباط ممکن نشد. در حال تلاش دوباره …",
    "Connection lost. Trying to reconnect …" : "ارتباط قطع شد. در حال تلاش برای اتصال دوباره …",
    "Connection problems …" : "مشکلات ارتباطی …",
    "Collapse" : "جمع کردن",
    "Expand" : "باز کردن",
    "You need to be logged in to upload files" : "برای آپلود فایل‌ها باید وارد سیستم شوید",
    "Drop your files to upload" : "فایل‌های خود را برای آپلود رها کنید",
    "Conversation messages" : "پیام‌های گفتگو",
    "Scroll to bottom" : "رفتن به پایین",
    "Post message" : "ارسال پیام",
    "Federated conversation" : "گفتگوی فدرال",
    "Public conversation" : "گفتگوی عمومی",
    "Favorite" : "مورد علاقه",
    "Banned users" : "کاربران مسدود شده",
    "Manage the list of banned users in this conversation." : "مدیریت لیست کاربران مسدود شده در این گفتگو",
    "Manage bans" : "مدیریت مسدود شده‌ها",
    "No banned users" : "کاربر مسدود شده‌ای وجود ندارد",
    "Banned by:" : "مسدود شده توسط:",
    "Date:" : "تاریخ:",
    "Note:" : "یادداشت:",
    "Hide details" : "مخفی کردن جزئیات",
    "Show details" : "نمایش جزئیات",
    "Unban" : "رفع مسدودیت",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "می‌توانید عنوان و توضیحات را در {linkstart}تقویم ↗{linkend} تغییر دهید.",
    "Error while updating conversation name" : "خطا در به‌روزرسانی نام گفتگو",
    "Error while updating conversation description" : "خطا در به‌روزرسانی توضیحات گفتگو",
    "Enter a name for this conversation" : "یک نام برای این گفتگو وارد کنید",
    "Edit conversation name" : "ویرایش نام گفتگو",
    "Edit conversation description" : "ویرایش توضیحات گفتگو",
    "Enter a description for this conversation" : "یک توضیح برای این گفتگو وارد کنید",
    "Picture" : "تصویر",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "ربات‌های زیر می‌توانند در این گفتگو فعال شوند. برای نصب ربات‌های بیشتر روی این سرور با مدیریت خود تماس بگیرید.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "هیچ رباتی روی این سرور نصب نشده است. برای نصب ربات‌ها با مدیریت خود تماس بگیرید.",
    "Disable" : "غیرفعال کردن",
    "Enable" : "فعال کردن",
    "The bot is not available anymore" : "ربات دیگر در دسترس نیست",
    "Breakout rooms" : "اتاق‌های فرعی",
    "Manage breakout rooms" : "مدیریت اتاق‌های فرعی",
    "Set up breakout rooms for this conversation" : "تنظیم اتاق‌های فرعی برای این گفتگو",
    "Please select a valid PNG or JPG file" : "لطفاً یک فایل PNG یا JPG معتبر انتخاب کنید",
    "Choose your conversation picture" : "تصویر گفتگوی خود را انتخاب کنید",
    "Choose" : "انتخاب",
    "Error setting conversation picture" : "خطا در تنظیم تصویر گفتگو",
    "Could not set the conversation picture: {error}" : "امکان تنظیم تصویر گفتگو وجود ندارد: {error}",
    "Error cropping conversation picture" : "خطا در برش تصویر گفتگو",
    "Error removing conversation picture" : "خطا در حذف تصویر گفتگو",
    "Set emoji as conversation picture" : "تنظیم ایموجی به عنوان تصویر گفتگو",
    "Set background color for conversation picture" : "تنظیم رنگ پس‌زمینه برای تصویر گفتگو",
    "Upload conversation picture" : "بارگذاری تصویر گفتگو",
    "Choose conversation picture from files" : "انتخاب تصویر گفتگو از فایل‌ها",
    "Remove conversation picture" : "حذف تصویر گفتگو",
    "The file must be a PNG or JPG" : "فایل باید PNG یا JPG باشد",
    "Set picture" : "تنظیم تصویر",
    "Default permissions modified for {conversationName}" : "مجوزهای پیش‌فرض برای {conversationName} تغییر یافت",
    "Could not modify default permissions for {conversationName}" : "امکان تغییر مجوزهای پیش‌فرض برای {conversationName} وجود ندارد",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "مجوزهای پیش‌فرض شرکت‌کنندگان در این گفتگو را ویرایش کنید. این تنظیمات بر مدیران تأثیر نمی‌گذارد.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "هر بار که مجوزها در این بخش تغییر کنند، مجوزهای سفارشی که قبلاً به شرکت‌کنندگان جداگانه اختصاص داده شده بود، از بین می‌روند.",
    "All permissions" : "همه مجوزها",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "شرکت‌کنندگان مجوز شروع تماس، پیوستن به تماس، فعال کردن صدا و تصویر و اشتراک‌گذاری صفحه را دارند.",
    "Participants can use all available features." : "شرکت‌کنندگان می‌توانند از تمام ویژگی‌های موجود استفاده کنند.",
    "Restricted" : "محدود",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "شرکت‌کنندگان می‌توانند به تماس‌ها بپیوندند، اما نمی‌توانند صدا، تصویر یا اشتراک‌گذاری صفحه را تا زمانی که یک مدیر به صورت دستی مجوزها را اعطا کند، فعال کنند.",
    "Participants get a reduced feature set until a moderator manually grants additional permissions." : "شرکت‌کنندگان تا زمانی که یک مدیر به صورت دستی مجوزهای اضافی را اعطا کند، مجموعه ویژگی‌های محدودی دریافت می‌کنند.",
    "Advanced permissions" : "مجوزهای پیشرفته",
    "Edit permissions" : "ویرایش مجوزها",
    "Conversation settings" : "تنظیمات گفتگو",
    "Basic Info" : "اطلاعات پایه",
    "Personal" : "شخصی",
    "Moderation" : "نظارت",
    "Setup overview" : "نمای کلی راه‌اندازی",
    "Live transcription" : "رونویسی زنده",
    "Live transcriptions app is not installed" : "برنامه رونویسی زنده نصب نشده است",
    "Enable live transcription" : "فعال‌سازی رونویسی زنده",
    "Breakout Rooms" : "اتاق‌های فرعی",
    "Matterbridge" : "Matterbridge",
    "Bots" : "ربات‌ها",
    "Danger zone" : "منطقه خطر",
    "Archive conversation" : "بایگانی گفتگو",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "گفتگوهای بایگانی‌شده به‌طور پیش‌فرض از لیست گفتگوها پنهان هستند. با این حال، هنگام جستجوی نام گفتگو یا دسترسی به لیست گفتگوهای بایگانی‌شده همچنان نمایش داده می‌شوند.",
    "Do you really want to leave \"{displayName}\"?" : "آیا واقعاً می‌خواهید از \"{displayName}\" خارج شوید؟",
    "You can archive this conversation instead." : "می‌توانید به جای آن این گفتگو را بایگانی کنید.",
    "Leave conversation" : "خروج از گفتگو",
    "You need to promote a new moderator before you can leave the conversation" : "قبل از خروج از گفتگو باید یک ناظر جدید تعیین کنید.",
    "Delete conversation" : "حذف گفتگو",
    "Do you really want to delete \"{displayName}\"?" : "آیا واقعاً می‌خواهید \"{displayName}\" را حذف کنید؟",
    "Error while deleting conversation" : "خطا در حذف گفتگو",
    "Delete all chat messages" : "حذف همه پیام‌های چت",
    "Do you really want to delete all messages in \"{displayName}\"?" : "آیا واقعاً می‌خواهید همه پیام‌های \"{displayName}\" را حذف کنید؟",
    "Error while clearing chat history" : "خطا در پاک کردن تاریخچه چت",
    "Be careful, these actions cannot be undone." : "مراقب باشید، این اقدامات قابل بازگشت نیستند.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "پس از خروج از یک گفتگو، برای پیوستن دوباره به یک گفتگوی بسته، نیاز به دعوتنامه است. یک گفتگوی باز در هر زمان قابل پیوستن مجدد است.",
    "Permanently delete this conversation." : "این گفتگو را به طور دائمی حذف کنید.",
    "Delete chat messages" : "حذف پیام‌های چت",
    "Permanently delete all the messages in this conversation." : "همه پیام‌های این گفتگو را به طور دائمی حذف کنید.",
    "Custom expiration time" : "زمان انقضای سفارشی",
    "Message expiration disabled" : "انقضای پیام غیرفعال است",
    "Message expiration set: {duration}" : "انقضای پیام تنظیم شد: {duration}",
    "Error when trying to set message expiration" : "خطا در تلاش برای تنظیم انقضای پیام",
    "Message expiration" : "انقضای پیام",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "پیام‌های چت می‌توانند پس از مدتی منقضی شوند. توجه: فایل‌های به اشتراک‌گذاشته‌شده در چت برای مالک حذف نخواهند شد، اما دیگر در گفتگو به اشتراک گذاشته نمی‌شوند.",
    "Set message expiration" : "تنظیم انقضای پیام",
    "Current message expiration" : "انقضای فعلی پیام",
    "Password copied to clipboard" : "رمز عبور در کلیپ‌بورد کپی شد",
    "Password could not be copied" : "رمز عبور قابل کپی شدن نبود",
    "Guest access" : "دسترسی مهمان",
    "Allow guests to join this conversation via link" : "اجازه دهید مهمانان از طریق لینک به این گفتگو بپیوندند",
    "Breakout rooms are not allowed in public conversations." : "اتاق‌های فرعی در گفتگوهای عمومی مجاز نیستند.",
    "Password protection" : "محافظت با رمز عبور",
    "This conversation is password-protected. Guests need password to join" : "این گفتگو با رمز عبور محافظت می‌شود. مهمانان برای پیوستن نیاز به رمز عبور دارند",
    "Password protection is needed for public conversations" : "محافظت با رمز عبور برای گفتگوهای عمومی ضروری است",
    "Set a password" : "تنظیم رمز عبور",
    "Change password" : "تغییر رمز عبور",
    "Enter new password" : "وارد کردن رمز عبور جدید",
    "Save password" : "ذخیره رمز عبور",
    "Copy password" : "کپی رمز عبور",
    "Guests are allowed to join this conversation via link" : "مهمان‌ها مجاز به پیوستن به این گفتگو از طریق لینک هستند",
    "Guests are not allowed to join this conversation" : "مهمان‌ها مجاز به پیوستن به این گفتگو نیستند",
    "Resend invitations" : "ارسال مجدد دعوت‌نامه‌ها",
    "This conversation is open to both registered users and users created with the Guests app" : "این گفتگو برای کاربران ثبت‌نام‌شده و کاربرانی که با برنامه مهمان ایجاد شده‌اند، باز است",
    "This conversation is open to registered users" : "این گفتگو برای کاربران ثبت‌نام‌شده باز است",
    "This conversation is limited to the current participants" : "این گفتگو به شرکت‌کنندگان فعلی محدود شده است",
    "You opened the conversation to both registered users and users created with the Guests app" : "شما گفتگو را برای کاربران ثبت‌نام‌شده و کاربرانی که با برنامه مهمان ایجاد شده‌اند، باز کردید",
    "Error occurred when opening or limiting the conversation" : "هنگام باز کردن یا محدود کردن گفتگو خطایی رخ داد",
    "Open conversation to registered users, showing it in search results" : "باز کردن گفتگو برای کاربران ثبت‌نام‌شده، نمایش آن در نتایج جستجو",
    "Also open to users created with the Guests app" : "همچنین برای کاربرانی که با برنامه مهمان ایجاد شده‌اند باز است",
    "Open conversation" : "باز کردن گفتگو",
    "Set language spoken in calls" : "تنظیم زبان گفتگو در تماس‌ها",
    "Languages could not be loaded" : "زبان‌ها بارگیری نشدند",
    "Loading languages …" : "در حال بارگذاری زبان‌ها …",
    "Invalid language" : "زبان نامعتبر",
    "Default language (English)" : "زبان پیش‌فرض (انگلیسی)",
    "Default live transcription language set" : "زبان پیش‌فرض رونویسی زنده تنظیم شد",
    "Live transcription language set: {languageName}" : "زبان رونویسی زنده تنظیم شد: {languageName}",
    "Error when trying to set live transcription language" : "خطا هنگام تلاش برای تنظیم زبان رونویسی زنده",
    "Start time: {date}" : "زمان شروع: {date}",
    "Start time has been updated" : "زمان شروع به‌روزرسانی شد",
    "Error occurred while updating start time" : "هنگام به‌روزرسانی زمان شروع خطایی رخ داد",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "فعال‌سازی لابی، افراد غیرمدیر را از تماس در حال انجام حذف می‌کند",
    "Enable lobby, restricting the conversation to moderators" : "فعال‌سازی لابی، محدود کردن گفتگو به مدیران",
    "Meeting start time" : "زمان شروع جلسه",
    "Start time (optional)" : "زمان شروع (اختیاری)",
    "Import email participants" : "وارد کردن شرکت‌کنندگان ایمیل",
    "You can import a list of email participants from a CSV file." : "می‌توانید لیستی از شرکت‌کنندگان ایمیل را از یک فایل CSV وارد کنید",
    "Poll drafts" : "پیش‌نویس‌های نظرسنجی",
    "Browse poll drafts" : "مرور پیش‌نویس‌های نظرسنجی",
    "Error occurred when locking the conversation" : "هنگام قفل کردن گفتگو خطایی رخ داد",
    "Error occurred when unlocking the conversation" : "هنگام باز کردن قفل گفتگو خطایی رخ داد",
    "Lock conversation" : "قفل کردن گفتگو",
    "This will also terminate the ongoing call." : "این کار همچنین تماس در حال انجام را خاتمه می‌دهد",
    "Lock the conversation to prevent anyone to post messages or start calls" : "گفتگو را قفل کنید تا از ارسال پیام یا شروع تماس توسط هر کسی جلوگیری شود",
    "Edit" : "ویرایش",
    "More information" : "اطلاعات بیشتر",
    "Delete" : "حذف",
    "Add new bridged channel to current conversation" : "افزودن کانال پل‌شده جدید به گفتگوی فعلی",
    "unknown state" : "وضعیت نامشخص",
    "running" : "در حال اجرا",
    "not running, check Matterbridge log" : "در حال اجرا نیست، گزارش Matterbridge را بررسی کنید",
    "not running" : "در حال اجرا نیست",
    "Bridge saved" : "پل ذخیره شد",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "می‌توانید کانال‌ها را از سیستم‌های پیام‌رسانی مختلف با Matterbridge پل کنید",
    "More info on Matterbridge" : "اطلاعات بیشتر درباره Matterbridge",
    "Messaging systems" : "سیستم‌های پیام‌رسانی",
    "Enable bridge" : "فعال‌سازی پل",
    "Show Matterbridge log" : "نمایش گزارش Matterbridge",
    "Log content" : "محتوای لاگ",
    "Only moderators are allowed to mention @all" : "فقط مدیران مجاز به منشن کردن @all هستند",
    "All participants are allowed to mention @all" : "همه شرکت‌کنندگان مجاز به منشن کردن @all هستند",
    "Participants are now allowed to mention @all." : "شرکت‌کنندگان اکنون مجاز به منشن کردن @all هستند",
    "Mentioning @all has been limited to moderators." : "منشن کردن @all به مدیران محدود شد",
    "Allow participants to mention @all" : "اجازه منشن کردن @all به شرکت‌کنندگان",
    "Mention permissions" : "مجوزهای منشن",
    "Notifications" : "اعلان‌ها",
    "Notify about calls in this conversation" : "اطلاع‌رسانی تماس‌ها در این گفتگو",
    "Important conversation" : "گفتگوی مهم",
    "\"Do not disturb\" user status is ignored for important conversations" : "وضعیت «مزاحم نشوید» کاربر برای گفتگوهای مهم نادیده گرفته می‌شود",
    "Sensitive conversation" : "گفتگوی حساس",
    "Message preview will be disabled in conversation list and notifications" : "پیش‌نمایش پیام در لیست گفتگوها و اعلان‌ها غیرفعال می‌شود",
    "Recording consent is required for calls in this conversation" : "رضایت ضبط برای تماس‌های این گفتگو الزامی است",
    "Recording consent is not required for calls in this conversation" : "رضایت ضبط برای تماس‌های این گفتگو الزامی نیست",
    "Recording consent requirement was updated" : "الزام رضایت ضبط به‌روزرسانی شد",
    "Error occurred while updating recording consent" : "هنگام به‌روزرسانی رضایت ضبط خطایی رخ داد",
    "Recording Consent" : "رضایت ضبط",
    "Recording consent cannot be changed once a call or breakout session has started." : "پس از شروع تماس یا جلسه گروهی، امکان تغییر رضایت ضبط وجود ندارد",
    "Require recording consent before joining call in this conversation" : "الزام رضایت ضبط قبل از پیوستن به تماس در این گفتگو",
    "Recording consent is required for all calls" : "رضایت ضبط برای همه تماس‌ها الزامی است",
    "SIP dial-in is now possible without PIN requirement" : "ورود از طریق SIP بدون نیاز به PIN امکان‌پذیر شد",
    "SIP dial-in is now enabled" : "ورود از طریق SIP اکنون فعال است",
    "SIP dial-in is now disabled" : "ورود از طریق SIP اکنون غیرفعال است",
    "Error occurred when enabling SIP dial-in" : "هنگام فعال‌سازی ورود از طریق SIP خطایی رخ داد",
    "Error occurred when disabling SIP dial-in" : "هنگام غیرفعال‌سازی ورود از طریق SIP خطایی رخ داد",
    "Phone and SIP dial-in" : "تلفن و ورود از طریق SIP",
    "Enable phone and SIP dial-in" : "فعال‌سازی تلفن و ورود از طریق SIP",
    "Allow to dial-in without a PIN" : "اجازه ورود بدون PIN",
    "Conversation token" : "توکن مکالمه",
    "Conversation" : "گفت‌وگو",
    "Ongoing" : "در حال انجام",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n person accepted","%n people accepted"],
    "_%n person declined_::_%n people declined_" : ["%n person declined","%n people declined"],
    "_and %n other attachment_::_and %n other attachments_" : ["and %n other attachment","and %n other attachments"],
    "With {displayName}" : "با {displayName}",
    "In {conversation}" : "در {conversation}",
    "View attachment" : "مشاهده پیوست",
    "Join" : "پیوستن",
    "View conversation" : "مشاهده گفتگو",
    "View event on Calendar" : "مشاهده رویداد در تقویم",
    "Error while creating the conversation" : "خطا در ایجاد گفتگو",
    "Hello, {displayName}" : "سلام، {displayName}",
    "Start meeting now" : "شروع جلسه هم‌اکنون",
    "Give your meeting a title" : "به جلسه خود عنوان دهید",
    "Create and copy link" : "ایجاد و کپی لینک",
    "Create a new conversation" : "ایجاد گفتگوی جدید",
    "Join open conversations" : "پیوستن به گفتگوهای باز",
    "Call a phone number" : "تماس با شماره تلفن",
    "Scroll backward" : "پیمایش به عقب",
    "Scroll forward" : "پیمایش به جلو",
    "Schedule meetings" : "زمان‌بندی جلسات",
    "You don't have any upcoming meetings" : "هیچ جلسه‌ای در پیش ندارید",
    "Calendar events with a conversation link as the location are shown here" : "رویدادهای تقویم که لینک مکالمه به عنوان مکان دارند در اینجا نمایش داده می‌شوند",
    "Open calendar" : "باز کردن تقویم",
    "Unread mentions" : "اشاره‌های خوانده نشده",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "پیام‌هایی که در آن به شما اشاره شده است در اینجا ظاهر می‌شوند. می‌توانید با تایپ @ و سپس نام فرد به دیگران اشاره کنید",
    "Upcoming reminders" : "یادآوری‌های پیش رو",
    "Message reminders" : "یادآوری پیام",
    "Set a reminder on a message to be notified" : "برای یک پیام یادآوری تنظیم کنید تا مطلع شوید",
    "Start a group conversation" : "شروع یک مکالمه گروهی",
    "Create conversation" : "ایجاد مکالمه",
    "Enter your name" : "نام خود را وارد کنید",
    "Submit name and join" : "ارسال نام و پیوستن",
    "Do you already have an account?" : "آیا قبلاً حساب کاربری دارید؟",
    "Log in" : "ورود",
    "Error while verifying uploaded file" : "خطا در تأیید فایل آپلود شده",
    "Uploaded file is verified" : "فایل آپلود شده تأیید شد",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match {sample1} or just {sample2}<br/>- One entry per line (e.g. {sample3})" : "فرمت محتوا مقادیر جدا شده با کاما (CSV) است:<br/>- خط هدر الزامی است و باید با {sample1} یا فقط {sample2} مطابقت داشته باشد<br/>- هر خط یک ورودی (مثلاً {sample3})",
    "Participants added successfully" : "شرکت‌کنندگان با موفقیت اضافه شدند",
    "Error while adding participants" : "خطا در افزودن شرکت‌کنندگان",
    "Import a file" : "وارد کردن یک فایل",
    "Browse" : "مرور",
    "Verifying uploaded file …" : "در حال راستی‌آزمایی پروندهٔ بارگذاری‌شده …",
    "This might take a moment" : "این ممکن است لحظه‌ای طول بکشد",
    "Send invitations" : "ارسال دعوت‌نامه‌ها",
    "_%n invalid email_::_%n invalid emails_" : ["%n invalid email","%n invalid emails"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n email is already imported or a duplicate","%n emails are already imported or duplicates"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n invitation can be sent","%n invitations can be sent"],
    "An error occurred while calling a phone number" : "هنگام تماس با یک شماره تلفن خطایی رخ داد",
    "Phone number could not be called: {error}" : "شماره تلفن قابل تماس نبود: {error}",
    "Phone number could not be called" : "شماره تلفن قابل تماس نبود",
    "Search participants or phone numbers" : "جستجوی شرکت‌کنندگان یا شماره تلفن‌ها",
    "Creating the conversation …" : "در حال ایجاد مکالمه …",
    "Mark as read" : "علامت‌گذاری به عنوان خوانده شده",
    "Mark as unread" : "علامت‌گذاری به عنوان خوانده نشده",
    "Remove from favorites" : "حذف از موارد دلخواه",
    "Add to favorites" : "افزودن به موارد دلخواه",
    "Unarchive conversation" : "خارج کردن مکالمه از بایگانی",
    "Ignore \"Do not disturb\"" : "نادیده گرفتن «مزاحم نشوید»",
    "You need to promote a new moderator before you can leave the conversation." : "قبل از ترک مکالمه باید یک ناظر جدید معرفی کنید.",
    "New tag" : "برچسب جدید",
    "Tag name" : "نام برچسب",
    "Conversation actions" : "اقدامات مکالمه",
    "Tags" : "برچسب‌ها",
    "Notify about calls" : "اطلاع‌رسانی درباره تماس‌ها",
    "Hide message text" : "مخفی کردن متن پیام",
    "Remove all tags" : "حذف همه برچسب‌ها",
    "Rename tag" : "تغییر نام برچسب",
    "Delete tag" : "حذف برچسب",
    "Do you really want to delete \"{name}\"? Conversations with this tag will be moved to \"Other\"." : "آیا واقعاً می‌خواهید \"{name}\" را حذف کنید؟ مکالمات با این برچسب به «سایر» منتقل می‌شوند.",
    "Move up" : "انتقال به بالا",
    "Move down" : "انتقال به پایین",
    "Pending invitations" : "دعوت‌نامه‌های در انتظار",
    "Join conversations from other servers" : "پیوستن به گفتگوهای سرورهای دیگر",
    "From {user} at {remoteServer}" : "از {user} در {remoteServer}",
    "Decline invitation" : "رد دعوت‌نامه",
    "Accept invitation" : "پذیرش دعوت‌نامه",
    "No pending invitations" : "هیچ دعوت‌نامه‌ای در انتظار نیست",
    "Home" : "خانه",
    "Unread" : "خوانده‌نشده",
    "Mentions" : "اشاره‌ها",
    "Meetings" : "جلسات",
    "Sort conversations" : "مرتب‌سازی گفتگوها",
    "By recent activity" : "بر اساس فعالیت اخیر",
    "Alphabetically" : "بر اساس حروف الفبا",
    "Do not group by type" : "گروه‌بندی بر اساس نوع انجام نشود",
    "Show private ones first" : "نمایش خصوصی‌ها اول",
    "Show group ones first" : "نمایش گروهی‌ها اول",
    "No followed threads" : "هیچ موضوع دنبال‌شده‌ای وجود ندارد",
    "No matches found" : "هیچ نتیجه‌ای یافت نشد",
    "No conversations found" : "هیچ گفتگویی یافت نشد",
    "You have no archived conversations." : "هیچ گفتگوی بایگانی‌شده‌ای ندارید.",
    "Subscribe to an existing thread or start your own." : "به یک موضوع موجود مشترک شوید یا موضوع خود را شروع کنید.",
    "You have no unread mentions." : "هیچ اشاره خوانده‌نشده‌ای ندارید.",
    "You have no unread messages." : "هیچ پیام خوانده‌نشده‌ای ندارید.",
    "An error occurred while performing the search" : "هنگام انجام جستجو خطایی رخ داد",
    "Conversation list" : "فهرست گفتگوها",
    "Filter conversations by" : "فیلتر کردن گفتگوها بر اساس",
    "Unread messages" : "پیام‌های خوانده‌نشده",
    "Meeting conversations" : "گفتگوهای جلسه",
    "Clear filters" : "پاک کردن فیلترها",
    "New personal note" : "یادداشت شخصی جدید",
    "SIP backend is not installed" : "پشتیبان SIP نصب نشده است",
    "Back to conversations" : "بازگشت به گفتگوها",
    "Threads" : "موضوعات",
    "Archived conversations" : "گفتگوهای بایگانی‌شده",
    "Clear filter" : "پاک کردن فیلتر",
    "Show more threads" : "نمایش موضوعات بیشتر",
    "App settings" : "تنظیمات برنامه",
    "Users" : "کاربران",
    "Groups" : "گروه‌ها",
    "Teams" : "تیم‌ها",
    "Federated users" : "کاربران فدرال",
    "New private conversation" : "گفتگوی خصوصی جدید",
    "Other sources" : "سایر منابع",
    "Open conversations" : "گفتگوهای باز",
    "No search results" : "هیچ نتیجه جستجویی وجود ندارد",
    "Users, groups and teams" : "کاربران، گروه‌ها و تیم‌ها",
    "Users and groups" : "کاربران و گروه‌ها",
    "Users and teams" : "کاربران و تیم‌ها",
    "Groups and teams" : "گروه‌ها و تیم‌ها",
    "New group conversation" : "گفتگوی گروهی جدید",
    "The meeting will start soon" : "جلسه به زودی شروع می‌شود",
    "This meeting is scheduled for {startTime}" : "این جلسه برای {startTime} برنامه‌ریزی شده است",
    "You are currently waiting in the lobby" : "شما در حال حاضر در لابی منتظر هستید",
    "Enable noise suppression" : "فعال‌سازی حذف نویز",
    "Reduce background noises for better voice quality" : "کاهش نویزهای پس‌زمینه برای کیفیت صدای بهتر",
    "Basic" : "پایه",
    "Advanced" : "پیشرفته",
    "Enable echo cancellation" : "فعال‌سازی حذف پژواک",
    "Minimize echo effect from own surrounding" : "کاهش اثر پژواک از محیط اطراف خود",
    "Enable auto gain control" : "فعال‌سازی کنترل خودکار بهره",
    "Dynamically adjust microphone volume for consistent level" : "تنظیم پویای حجم میکروفون برای سطح یکنواخت",
    "Select microphone" : "انتخاب میکروفون",
    "No microphone available" : "هیچ میکروفونی در دسترس نیست",
    "Select speaker" : "انتخاب بلندگو",
    "No speaker available" : "هیچ بلندگویی در دسترس نیست",
    "Select camera" : "انتخاب دوربین",
    "No camera available" : "هیچ دوربینی در دسترس نیست",
    "Select a device" : "انتخاب یک دستگاه",
    "Playing …" : "در حال پخش …",
    "Test speakers" : "تست بلندگوها",
    "Test" : "تست",
    "Devices" : "دستگاه‌ها",
    "Backgrounds" : "پس‌زمینه‌ها",
    "No audio" : "بدون صدا",
    "No camera" : "بدون دوربین",
    "Display video as you will see it (mirrored)" : "نمایش ویدیو همانطور که خودتان می‌بینید (آینه‌ای)",
    "Display video as others will see it" : "نمایش ویدیو همانطور که دیگران می‌بینند",
    "Calls are not supported in your browser" : "تماس‌ها در مرورگر شما پشتیبانی نمی‌شوند",
    "Access to microphone is only possible with HTTPS" : "دسترسی به میکروفون فقط با HTTPS امکان‌پذیر است",
    "Access to microphone was denied" : "دسترسی به میکروفون رد شد",
    "Error while accessing microphone" : "خطا در دسترسی به میکروفون",
    "Access to camera is only possible with HTTPS" : "دسترسی به دوربین فقط با HTTPS امکان‌پذیر است",
    "The call is being recorded." : "تماس در حال ضبط است.",
    "The call might be recorded." : "ممکن است تماس ضبط شود.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "ضبط ممکن است شامل صدای شما، ویدیوی دوربین و اشتراک‌گذاری صفحه باشد. قبل از پیوستن به تماس، رضایت شما الزامی است.",
    "Give consent to the recording of this call" : "رضایت خود را برای ضبط این تماس اعلام کنید",
    "You can only join a voice room via a call." : "شما فقط می‌توانید از طریق یک تماس به اتاق صوتی بپیوندید.",
    "Show more info" : "نمایش اطلاعات بیشتر",
    "Audio is not available" : "صدا در دسترس نیست",
    "Video is not available" : "ویدیو در دسترس نیست",
    "Start recording immediately with the call" : "شروع ضبط بلافاصله با تماس",
    "Recording backend is not installed" : "بک‌اند ضبط نصب نشده است",
    "Notify all participants about this call" : "اطلاع‌رسانی به همه شرکت‌کنندگان درباره این تماس",
    "Apply settings" : "اعمال تنظیمات",
    "Select virtual office background" : "انتخاب پس‌زمینه مجازی اداری",
    "Select virtual home background" : "انتخاب پس‌زمینه مجازی خانگی",
    "Select virtual abstract background" : "انتخاب پس‌زمینه مجازی انتزاعی",
    "Select virtual beach background" : "انتخاب پس‌زمینه مجازی ساحلی",
    "Select virtual park background" : "انتخاب پس‌زمینه پارک مجازی",
    "Select virtual theater background" : "انتخاب پس‌زمینه تئاتر مجازی",
    "Select virtual library background" : "انتخاب پس‌زمینه کتابخانه مجازی",
    "Select virtual space station background" : "انتخاب پس‌زمینه ایستگاه فضایی مجازی",
    "Error while uploading the file" : "خطا در آپلود فایل",
    "Select a file" : "انتخاب یک فایل",
    "Invalid path selected" : "مسیر نامعتبر انتخاب شد",
    "Select virtual background from file {fileName}" : "انتخاب پس‌زمینه مجازی از فایل {fileName}",
    "Blur" : "محو کردن",
    "Upload" : "آپلود",
    "Files" : "فایل‌ها",
    "(editing)" : "(در حال ویرایش)",
    "(edited)" : "(ویرایش شده)",
    "The message has expired or has been deleted" : "پیام منقضی شده یا حذف شده است",
    "Cancel quote" : "لغو نقل‌قول",
    "24 hours" : "۲۴ ساعت",
    "7 days" : "۷ روز",
    "30 days" : "۳۰ روز",
    "Until unpin" : "تا زمان سنجاق‌زدایی",
    "Clear reminder – {timeLocale}" : "پاک کردن یادآور – {timeLocale}",
    "Edited by {actor}" : "ویرایش شده توسط {actor}",
    "Pinned by you" : "سنجاق شده توسط شما",
    "Pinned by {actor}" : "سنجاق شده توسط {actor}",
    "Until {absoluteDate}" : "تا {absoluteDate}",
    "Message text copied to clipboard" : "متن پیام در کلیپ‌بورد کپی شد",
    "Message text could not be copied" : "متن پیام قابل کپی شدن نبود",
    "Message forwarded to \"Note to self\"" : "پیام به \"یادداشت برای خود\" ارسال شد",
    "Error while forwarding message to \"Note to self\"" : "خطا در ارسال پیام به \"یادداشت برای خود\"",
    "A reminder was successfully removed" : "یادآوری با موفقیت حذف شد",
    "Error occurred when removing a reminder" : "خطا در حذف یادآوری",
    "A reminder was successfully set at {datetime}" : "یادآوری با موفقیت در {datetime} تنظیم شد",
    "Error occurred when creating a reminder" : "خطا در ایجاد یادآوری",
    "Add a reaction to this message" : "افزودن واکنش به این پیام",
    "Reply" : "پاسخ",
    "More actions" : "اقدامات بیشتر",
    "Set reminder" : "تنظیم یادآوری",
    "Pin message" : "سنجاق کردن پیام",
    "Unpin message" : "برداشتن سنجاق پیام",
    "Reply privately" : "پاسخ خصوصی",
    "Edit message" : "ویرایش پیام",
    "Copy message" : "کپی پیام",
    "Copy message link" : "کپی لینک پیام",
    "Go to file" : "رفتن به فایل",
    "Download file" : "دانلود فایل",
    "Go to thread" : "رفتن به تاپیک",
    "Edit thread details" : "ویرایش جزئیات تاپیک",
    "Forward message" : "ارسال پیام",
    "Translate" : "ترجمه",
    "Set custom reminder" : "تنظیم یادآوری سفارشی",
    "Keep pinned for" : "سنجاق نگه داشتن برای",
    "Set custom period" : "تنظیم بازه زمانی دلخواه",
    "Close reactions menu" : "بستن منوی واکنش‌ها",
    "React with {emoji}" : "واکنش با {emoji}",
    "React with another emoji" : "واکنش با ایموجی دیگر",
    "Choose a conversation to forward the selected message." : "انتخاب گفتگویی برای ارسال پیام انتخاب‌شده.",
    "Error while forwarding message" : "خطا در ارسال پیام",
    "The message has been forwarded to {selectedConversationName}" : "پیام به {selectedConversationName} ارسال شد",
    "Dismiss" : "رد کردن",
    "Go to conversation" : "رفتن به گفتگو",
    "Detect language" : "تشخیص زبان",
    "The message could not be translated" : "پیام قابل ترجمه نبود",
    "Translation copied to clipboard" : "ترجمه در کلیپ‌بورد کپی شد",
    "Translation could not be copied" : "ترجمه قابل کپی شدن نبود",
    "Translate message" : "ترجمه پیام",
    "Source language to translate from" : "زبان مبدأ برای ترجمه",
    "Translate from" : "ترجمه از",
    "Target language to translate into" : "زبان مقصد برای ترجمه",
    "Translate to" : "ترجمه به",
    "Translating" : "در حال ترجمه",
    "This translation is AI generated and may contain mistakes." : "این ترجمه توسط هوش مصنوعی تولید شده و ممکن است حاوی اشتباه باشد.",
    "Copy translated text" : "کپی متن ترجمه‌شده",
    "Error when scheduling the message" : "خطا در زمان‌بندی پیام",
    "Reschedule" : "زمان‌بندی مجدد",
    "Send now" : "ارسال الآن",
    "Choose a time" : "انتخاب زمان",
    "Send at custom time" : "ارسال در زمان دلخواه",
    "Will be sent without notification" : "بدون اعلان ارسال خواهد شد",
    "Message read by everyone who shares their reading status" : "پیام توسط همه کسانی که وضعیت خواندن خود را به اشتراک می‌گذارند، خوانده شد",
    "Message sent" : "پیام ارسال شد",
    "Sent without notification" : "بدون اعلان ارسال شد",
    "Deleting message" : "در حال حذف پیام",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "پیام با موفقیت حذف شد، اما یک ربات یا Matterbridge پیکربندی شده است و ممکن است پیام قبلاً به سرویس‌های دیگر توزیع شده باشد",
    "Message deleted successfully" : "پیام با موفقیت حذف شد",
    "Message could not be deleted because it is too old" : "پیام به دلیل قدیمی بودن قابل حذف نیست",
    "Only normal chat messages can be deleted" : "فقط پیام‌های معمولی چت قابل حذف هستند",
    "An error occurred while deleting the message" : "هنگام حذف پیام خطایی رخ داد",
    "Pinned" : "سنجاق شده",
    "Your browser does not support playing audio files" : "مرورگر شما از پخش فایل‌های صوتی پشتیبانی نمی‌کند",
    "Contact" : "مخاطب",
    "{stack} in {board}" : "{stack} در {board}",
    "Deck Card" : "کارت کارتابل",
    "Remove {fileName}" : "حذف {fileName}",
    "Open this location in OpenStreetMap" : "باز کردن این مکان در OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n reply","%n replies"],
    "Sending message" : "در حال ارسال پیام",
    "Failed to send the message. Click to try again" : "ارسال پیام ناموفق بود. برای تلاش مجدد کلیک کنید",
    "Not enough free space to upload file" : "فضای خالی کافی برای آپلود فایل وجود ندارد",
    "You cannot send messages to this conversation at the moment" : "در حال حاضر نمی‌توانید به این گفتگو پیام ارسال کنید",
    "Could not update the message" : "امکان به‌روزرسانی پیام وجود نداشت",
    "Reply to thread \"{threadTitle}\"" : "پاسخ به تاپیک \"{threadTitle}\"",
    "_You voted • %n vote_::_You voted • %n votes_" : ["شما رای دادید • %n رای","شما رای دادید • %n رای"],
    "You voted" : "شما رای دادید",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["برای رای دادن کلیک کنید • %n رای","برای رای دادن کلیک کنید • %n رای"],
    "Click to vote" : "برای رای دادن کلیک کنید",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["پیش‌نویس نظرسنجی • %n گزینه","پیش‌نویس نظرسنجی • %n گزینه"],
    "_%n vote_::_%n votes_" : ["%n vote","%n ÿ±ÿß€å"],
    "Edit poll draft" : "ویرایش پیش‌نویس نظرسنجی",
    "Delete poll draft" : "حذف پیش‌نویس نظرسنجی",
    "Open poll" : "نظرسنجی باز",
    "Closed poll" : "نظرسنجی بسته",
    "See results" : "مشاهده نتایج",
    "Reactions" : "واکنش‌ها",
    "No permission to post reactions in this conversation" : "مجوز ارسال واکنش در این گفتگو را ندارید",
    "and {participant}" : "و {participant}",
    "_and %n other participant_::_and %n other participants_" : ["and %n other participant","and %n other participants"],
    "Show all reactions" : "نمایش همه واکنش‌ها",
    "Add more reactions" : "افزودن واکنش‌های بیشتر",
    "Show or collapse system messages" : "نمایش یا جمع‌آوری پیام‌های سیستمی",
    "No messages" : "پیامی وجود ندارد",
    "All messages have expired or have been deleted." : "همه پیام‌ها منقضی شده یا حذف شده‌اند.",
    "Generate summary with AI" : "تولید خلاصه با هوش مصنوعی",
    "{author} (pinned by you)" : "{author} (سنجاق‌شده توسط شما)",
    "{author} (pinned by {actor})" : "{author} (سنجاق‌شده توسط {actor})",
    "Unpin" : "برداشتن سنجاق",
    "Cancel search" : "لغو جستجو",
    "Add a phone number" : "افزودن شماره تلفن",
    "Error: A password is required to create the conversation." : "خطا: برای ایجاد گفتگو، رمز عبور الزامی است.",
    "All set, the conversation \"{conversationName}\" was created." : "همه چیز آماده است، گفتگوی \"{conversationName}\" ایجاد شد.",
    "Create a new group conversation" : "ایجاد یک گفتگوی گروهی جدید",
    "Add participants" : "افزودن شرکت‌کنندگان",
    "Maximum length exceeded ({maxlength} characters)" : "حداکثر طول مجاز بیش از حد شده است ({maxlength} کاراکتر)",
    "Conversation type" : "نوع گفتگو",
    "Default parameters are:" : "پارامترهای پیش‌فرض عبارتند از:",
    "These settings can be changed once the conversation is created." : "این تنظیمات پس از ایجاد گفتگو قابل تغییر هستند.",
    "Conversation visibility" : "قابلیت مشاهده گفتگو",
    "Allow guests to join via link" : "اجازه پیوستن مهمانان از طریق لینک",
    "Enter password" : "وارد کردن رمز عبور",
    "This conversation has been locked" : "این گفتگو قفل شده است",
    "No permission to post messages in this conversation" : "مجوز ارسال پیام در این گفتگو را ندارید",
    "Joining conversation …" : "در حال پیوستن به مکالمه …",
    "Write a message without notification" : "نوشتن پیام بدون اعلان",
    "Create a thread silently" : "ایجاد یک تاپیک بی‌صدا",
    "Create a thread" : "ایجاد یک تاپیک",
    "Send message silently" : "ارسال پیام بی‌صدا",
    "Send message" : "ارسال پیام",
    "Send without notification" : "ارسال بدون اعلان",
    "The participant will not be notified about new messages" : "شرکت‌کننده از پیام‌های جدید مطلع نخواهد شد",
    "Participants will not be notified about new messages" : "شرکت‌کنندگان از پیام‌های جدید مطلع نخواهند شد",
    "Message will be sent {datetimeString}" : "پیام در {datetimeString} ارسال خواهد شد",
    "Thread title is required" : "عنوان تاپیک الزامی است",
    "Message text is required" : "متن پیام الزامی است",
    "The message could not be edited" : "امکان ویرایش پیام وجود نداشت",
    "File to share" : "فایل برای اشتراک‌گذاری",
    "File upload is not available in this conversation" : "آپلود فایل در این گفتگو در دسترس نیست",
    "Message was successfully scheduled" : "پیام با موفقیت زمان‌بندی شد",
    "Add emoji" : "افزودن ایموجی",
    "Adding a mention will only notify users who did not read the message." : "افزودن اشاره فقط کاربرانی را مطلع می‌کند که پیام را نخوانده‌اند.",
    "Thread title" : "عنوان موضوع",
    "Send later" : "ارسال بعداً",
    "Show scheduled messages" : "نمایش پیام‌های زمان‌بندی‌شده",
    "Cancel editing" : "لغو ویرایش",
    "Schedule message" : "زمان‌بندی پیام",
    "{user} is out of office and might not respond." : "{user} در مرخصی است و ممکن است پاسخ ندهد.",
    "Absence period: {startDate} - {endDate}" : "دوره غیبت: {startDate} - {endDate}",
    "Replacement:" : "جایگزین:",
    "Share from {nextcloud}" : "اشتراک‌گذاری از {nextcloud}",
    "Share from Files" : "اشتراک‌گذاری از فایل‌ها",
    "Share files to the conversation" : "اشتراک‌گذاری فایل‌ها در گفتگو",
    "Upload from device" : "آپلود از دستگاه",
    "Create new poll" : "ایجاد نظرسنجی جدید",
    "Smart picker" : "انتخاب‌گر هوشمند",
    "Record voice message" : "ضبط پیام صوتی",
    "End recording and send" : "پایان ضبط و ارسال",
    "Dismiss recording" : "رد کردن ضبط",
    "Access to the microphone was denied" : "دسترسی به میکروفون رد شد",
    "Microphone either not available or disabled in settings" : "میکروفون در دسترس نیست یا در تنظیمات غیرفعال است",
    "Error while recording audio" : "خطا در حین ضبط صدا",
    "Voice message {time} ({conversation})" : "پیام صوتی {time} ({conversation})",
    "Generating summary of unread messages …" : "در حال تولید خلاصه‌ای از پیام‌های خوانده‌نشده …",
    "Summary is AI generated and might contain mistakes" : "خلاصه توسط هوش مصنوعی تولید شده و ممکن است حاوی اشتباه باشد",
    "Error occurred during a summary generation" : "خطایی در حین تولید خلاصه رخ داد",
    "New file" : "فایل جدید",
    "Blank" : "خالی",
    "Error while creating file" : "خطا در حین ایجاد فایل",
    "Create and share a new file" : "ایجاد و اشتراک‌گذاری یک فایل جدید",
    "Name of the new file" : "نام فایل جدید",
    "Create file" : "ایجاد فایل",
    "Someone is typing …" : "کسی در حال تایپ است …",
    "{user1} is typing …" : "{user1} در حال نوشتن است …",
    "{user1} and {user2} are typing …" : "{user1} و {user2} در حال نوشتن هستند …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}، {user2} و {user3} در حال نوشتن هستند …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}، {user2}، {user3} و %n نفر دیگر در حال نوشتن هستند …","{user1}، {user2}، {user3} و %n نفر دیگر در حال نوشتن هستند …"],
    "Add more files" : "افزودن فایل‌های بیشتر",
    "Send" : "ارسال",
    "In this conversation <strong>{user}</strong> can:" : "در این گفتگو <strong>{user}</strong> می‌تواند:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "ویرایش مجوزهای پیش‌فرض برای شرکت‌کنندگان در <strong>{conversationName}</strong>",
    "Start a call" : "شروع یک تماس",
    "Skip the lobby" : "رد شدن از لابی",
    "Can post messages" : "می‌تواند پیام ارسال کند",
    "Can post messages and reactions" : "می‌تواند پیام و واکنش ارسال کند",
    "Can add reactions" : "می‌توانید واکنش اضافه کنید",
    "Enable the microphone" : "فعال کردن میکروفون",
    "Enable the camera" : "فعال کردن دوربین",
    "Share the screen" : "اشتراک‌گذاری صفحه",
    "Update permissions" : "به‌روزرسانی مجوزها",
    "Updating permissions" : "در حال به‌روزرسانی مجوزها",
    "No poll drafts" : "هیچ پیش‌نویس نظرسنجی وجود ندارد",
    "There is no poll drafts yet saved for this conversation" : "هنوز هیچ پیش‌نویس نظرسنجی برای این گفتگو ذخیره نشده است",
    "Create poll in {name}" : "ایجاد نظرسنجی در {name}",
    "Create poll" : "ایجاد نظرسنجی",
    "Error while importing poll" : "خطا در وارد کردن نظرسنجی",
    "Question" : "سوال",
    "Ask a question" : "یک سوال بپرسید",
    "Import draft from file" : "وارد کردن پیش‌نویس از فایل",
    "Answers" : "گزینه‌ها",
    "Answer {option}" : "گزینه {option}",
    "Delete poll option" : "حذف گزینه نظرسنجی",
    "Add answer" : "افزودن پاسخ",
    "Settings" : "تنظیمات",
    "Anonymous poll" : "نظرسنجی ناشناس",
    "Multiple answers" : "پاسخ‌های چندگانه",
    "Save as draft" : "ذخیره به عنوان پیش‌نویس",
    "Export draft to file" : "خروجی پیش‌نویس به فایل",
    "_Final results • %n vote_::_Final results • %n votes_" : ["نتایج نهایی • %n رای","نتایج نهایی • %n رای"],
    "_%n vote • Your vote is anonymous_::_%n votes • Your vote is anonymous_" : ["%n رای • رای شما ناشناس است","%n رای • رای شما ناشناس است"],
    "Your vote is anonymous" : "رای شما ناشناس است",
    "You voted for this option" : "شما به این گزینه رای داده‌اید",
    "End poll" : "پایان نظرسنجی",
    "Change your vote" : "تغییر رای شما",
    "Withdraw vote" : "لغو رای",
    "Results" : "نتایج",
    "Download as spreadsheet" : "دانلود به عنوان صفحه گسترده",
    "Download as CSV" : "دانلود به عنوان CSV",
    "Voted participants" : "شرکت‌کنندگان رای‌دهنده",
    "Send a message to \"{roomName}\"" : "ارسال پیام به \"{roomName}\"",
    "Hide list of participants" : "مخفی کردن لیست شرکت‌کنندگان",
    "Show list of participants" : "نمایش لیست شرکت‌کنندگان",
    "Assistance requested in {roomName}" : "درخواست کمک در {roomName}",
    "The message was sent to \"{roomName}\"" : "پیام به \"{roomName}\" ارسال شد",
    "Dismiss request for assistance" : "رد درخواست کمک",
    "Send message to room" : "ارسال پیام به اتاق",
    "Back to main room" : "بازگشت به اتاق اصلی",
    "Back to your room" : "بازگشت به اتاق شما",
    "Message all rooms" : "پیام به همه اتاق‌ها",
    "Start session" : "شروع جلسه",
    "Start a call before you start a breakout room session" : "قبل از شروع جلسه اتاق‌های گروهی، یک تماس شروع کنید",
    "Stop session" : "توقف جلسه",
    "The message was sent to all breakout rooms" : "پیام به همه اتاق‌های گروهی ارسال شد",
    "Send a message to all breakout rooms" : "ارسال پیام به همه اتاق‌های گروهی",
    "Breakout rooms are not started" : "اتاق‌های گروهی شروع نشده‌اند",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "تماس‌های بدون بک‌اند با عملکرد بالا می‌توانند باعث مشکلات اتصال و بار زیاد روی دستگاه‌ها شوند. {linkstart}بیشتر بدانید{linkend}",
    "Talk setup incomplete" : "تنظیمات Talk ناقص است",
    "Disable lobby" : "غیرفعال کردن لابی",
    "Settings for participant \"{user}\"" : "تنظیمات برای شرکت‌کننده \"{user}\"",
    "Participant \"{user}\"" : "شرکت‌کننده \"{user}\"",
    "moderator" : "مدیر",
    "bot" : "ربات",
    "guest" : "مهمان",
    "Ringing …" : "در حال زنگ خوردن …",
    "Call rejected" : "تماس رد شد",
    "{time} talking …" : "{time} در حال صحبت …",
    "{time} talking time" : "زمان صحبت {time}",
    "Raised their hand" : "دست خود را بالا برده است",
    "Joined with video" : "با ویدیو پیوست",
    "Joined via phone" : "از طریق تلفن پیوست",
    "Joined with audio" : "با صدا پیوست",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "متن باید کمتر یا برابر {maxLength} کاراکتر باشد. متن فعلی شما {charactersCount} کاراکتر است.",
    "Remove group and members" : "حذف گروه و اعضا",
    "Remove team and members" : "حذف تیم و اعضا",
    "Remove participant" : "حذف شرکت‌کننده",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "آیا واقعاً می‌خواهید گروه \"{displayName}\" و اعضای آن را از این گفتگو حذف کنید؟",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "آیا واقعاً می‌خواهید تیم \"{displayName}\" و اعضای آن را از این گفتگو حذف کنید؟",
    "Do you really want to remove {displayName} from this conversation?" : "آیا واقعاً می‌خواهید {displayName} را از این گفتگو حذف کنید؟",
    "Notification was sent to {displayName}" : "اعلان به {displayName} ارسال شد",
    "Could not send notification to {displayName}" : "امکان ارسال اعلان به {displayName} وجود نداشت",
    "Permissions granted to {displayName}" : "دسترسی‌ها به {displayName} اعطا شد",
    "Could not modify permissions for {displayName}" : "امکان تغییر دسترسی‌ها برای {displayName} وجود نداشت",
    "Permissions removed for {displayName}" : "دسترسی‌ها برای {displayName} حذف شد",
    "Permissions set to default for {displayName}" : "دسترسی‌ها برای {displayName} به حالت پیش‌فرض بازگشت",
    "Phone number could not be hung up" : "شماره تلفن قطع نشد",
    "Phone number could not be put on hold" : "شماره تلفن در حالت انتظار قرار نگرفت",
    "Phone number could not be muted" : "شماره تلفن بی‌صدا نشد",
    "Phone number could not be unmuted" : "شماره تلفن از حالت بی‌صدا خارج نشد",
    "DTMF message could not be sent" : "پیام DTMF ارسال نشد",
    "Phone number copied to clipboard" : "شماره تلفن در کلیپ‌بورد کپی شد",
    "Phone number could not be copied" : "شماره تلفن کپی نشد",
    "in the lobby" : "در لابی",
    "Dial out phone" : "شماره‌گیری تلفن",
    "Hang up phone" : "قطع تماس تلفنی",
    "Move back to lobby" : "بازگشت به لابی",
    "Move to conversation" : "انتقال به گفتگو",
    "Dial-in PIN" : "PIN ورود",
    "Demote from moderator" : "تنزل از مدیر",
    "Promote to moderator" : "ارتقا به مدیر",
    "Resend invitation" : "ارسال مجدد دعوتنامه",
    "Send call notification" : "ارسال اعلان تماس",
    "Dial out phone number" : "شماره‌گیری تلفن",
    "Resume call for phone number" : "ادامه تماس برای شماره تلفن",
    "Put phone number on hold" : "قرار دادن شماره تلفن در حالت انتظار",
    "Unmute phone number" : "خارج کردن شماره تلفن از حالت بی‌صدا",
    "Mute phone number" : "بی‌صدا کردن شماره تلفن",
    "Copy phone number" : "کپی شماره تلفن",
    "Reset custom permissions" : "بازنشانی مجوزهای سفارشی",
    "Grant all permissions" : "اعطای همه مجوزها",
    "Remove all permissions" : "حذف همه مجوزها",
    "Also ban from this conversation" : "همچنین از این گفتگو مسدود شود",
    "Internal note (reason to ban)" : "یادداشت داخلی (دلیل مسدودیت)",
    "Remove" : "حذف",
    "Permissions modified for {displayName}" : "مجوزها برای {displayName} تغییر یافت",
    "Add users, groups or teams" : "افزودن کاربران، گروه‌ها یا تیم‌ها",
    "Add users or groups" : "افزودن کاربران یا گروه‌ها",
    "Add users or teams" : "افزودن کاربران یا تیم‌ها",
    "Add users" : "افزودن کاربران",
    "Add groups or teams" : "افزودن گروه‌ها یا تیم‌ها",
    "Add groups" : "افزودن گروه‌ها",
    "Add teams" : "افزودن تیم‌ها",
    "Add other sources" : "افزودن منابع دیگر",
    "Add emails" : "افزودن ایمیل‌ها",
    "Integrations" : "یکپارچه‌سازی‌ها",
    "Add federated users" : "افزودن کاربران فدرال",
    "Searching …" : "جستجوکردن …",
    "Search for more users" : "جستجوی کاربران بیشتر",
    "You can search or add participants via name, email, or Federated Cloud ID" : "می‌توانید شرکت‌کنندگان را با نام، ایمیل یا شناسه ابر فدرال جستجو یا اضافه کنید",
    "Search or add participants" : "جستجو یا افزودن شرکت‌کنندگان",
    "Invitation was sent to {actorId}" : "دعوت‌نامه به {actorId} ارسال شد",
    "An error occurred while adding the participants" : "هنگام افزودن شرکت‌کنندگان خطایی رخ داد",
    "A new group conversation with selected participant will be created" : "یک گفتگوی گروهی جدید با شرکت‌کننده انتخاب‌شده ایجاد خواهد شد",
    "Participants" : "شرکت‌کنندگان",
    "Pinned by a deleted user" : "سنجاق‌شده توسط کاربر حذف‌شده",
    "Participants ({count})" : "شرکت‌کنندگان ({count})",
    "Open chat" : "باز کردن گفتگو",
    "You have new unread messages in the chat." : "پیام‌های خوانده‌نشده جدیدی در گفتگو دارید.",
    "You have been mentioned in the chat." : "در گفتگو از شما نام برده شده است.",
    "Search messages" : "جستجوی پیام‌ها",
    "Chat" : "گفتگو",
    "Details" : "جزئیات",
    "Shared items" : "موارد اشتراک‌گذاری‌شده",
    "Search in {name}" : "جستجو در {name}",
    "Threads in {name}" : "موضوع‌ها در {name}",
    "{actor} in {conversation}" : "{actor} در {conversation}",
    "Search messages …" : "جستجوی پیام‌ها …",
    "Search options" : "گزینه‌های جستجو",
    "From User" : "از کاربر",
    "Since" : "از تاریخ",
    "Until" : "تا تاریخ",
    "No results found" : "نتیجه‌ای یافت نشد",
    "Load more results" : "بارگذاری نتایج بیشتر",
    "Recent threads" : "موضوع‌های اخیر",
    "Projects" : "پروژه‌ها",
    "No shared items" : "هیچ مورد اشتراک‌گذاری‌شده‌ای وجود ندارد",
    "Thread notifications" : "اعلان‌های موضوع",
    "Thread actions" : "اقدامات موضوع",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "پیوند به یک گفتگو",
    "No open conversations found" : "هیچ گفتگوی بازی یافت نشد",
    "Either there are no open conversations or you joined all of them." : "یا هیچ گفتگوی بازی وجود ندارد یا شما به همه آن‌ها پیوسته‌اید.",
    "Check spelling or use complete words." : "املای کلمات را بررسی کنید یا از کلمات کامل استفاده کنید.",
    "Search conversations or users" : "جستجوی گفتگوها یا کاربران",
    "Select conversation" : "انتخاب گفتگو",
    "Number length is not valid" : "طول شماره معتبر نیست",
    "Region code is not valid" : "کد منطقه معتبر نیست",
    "Number length is too short" : "طول شماره بسیار کوتاه است",
    "Number length is too long" : "طول شماره بسیار بلند است",
    "Number is not valid" : "شماره معتبر نیست",
    "Phone numbers" : "شماره تلفن‌ها",
    "Display name: {name}" : "نام نمایشی: {name}",
    "Edit display name" : "ویرایش نام نمایشی",
    "Display name (required)" : "نام نمایشی (الزامی)",
    "Save name" : "ذخیره نام",
    "I picked message bubbles" : "من حباب‌های پیام را انتخاب کردم",
    "I picked the list style" : "من سبک لیست را انتخاب کردم",
    "Error while setting personal setting" : "خطا در تنظیم تنظیمات شخصی",
    "Error while saving sounds setting" : "خطا در ذخیره تنظیمات صدا",
    "Compact conversations list" : "فشرده‌سازی لیست گفتگوها",
    "Chat appearance" : "ظاهر گفتگو",
    "Messages list" : "لیست پیام‌ها",
    "Message bubbles" : "حباب‌های پیام",
    "Play sounds when participants join or leave a call" : "پخش صدا هنگام ورود یا خروج شرکت‌کنندگان از تماس",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "در حال حاضر به دلیل محدودیت‌های فنی سازنده در آیفون و آیپد در دسترس نیست",
    "Notification settings" : "تنظیمات اعلان",
    "Sounds for chat and call notifications" : "صداهای اعلان گفتگو و تماس",
    "Invalid language ({languageId})" : "زبان نامعتبر ({languageId})",
    "Default language" : "زبان پیش‌فرض",
    "Default language ({languageName})" : "زبان پیش‌فرض ({languageName})",
    "Error when trying to load the available live translation languages" : "خطا در بارگذاری زبان‌های ترجمه زنده موجود",
    "Error when trying to set live translation language" : "خطا در تنظیم زبان ترجمه زنده",
    "Set language used to show the transcriptions" : "تنظیم زبان مورد استفاده برای نمایش رونوشت‌ها",
    "Select location for attachments" : "انتخاب مکان برای پیوست‌ها",
    "Error while setting attachment folder" : "خطا در تنظیم پوشه پیوست",
    "Error while setting read status privacy" : "خطا در تنظیم حریم خصوصی وضعیت خواندن",
    "Error while setting typing status privacy" : "خطا در تنظیم حریم خصوصی وضعیت تایپ",
    "Error while setting default media state" : "خطا در تنظیم حالت پیش‌فرض رسانه",
    "Turn camera and microphone off by default" : "خاموش کردن دوربین و میکروفن به طور پیش‌فرض",
    "Blur camera background by default" : "محو کردن پس‌زمینه دوربین به طور پیش‌فرض",
    "Skip device preview before joining a call" : "رد کردن پیش‌نمایش دستگاه قبل از پیوستن به تماس",
    "Camera will be turned off when joining. Always shown if recording consent is required." : "دوربین هنگام پیوستن خاموش خواهد شد. در صورت نیاز به رضایت ضبط، همیشه نشان داده می‌شود.",
    "Appearance & Sounds" : "ظاهر و صداها",
    "Privacy" : "حریم خصوصی",
    "Send read receipts" : "ارسال تأییدیه خواندن",
    "When off, all read statuses will be hidden" : "وقتی خاموش است، همه وضعیت‌های خواندن پنهان می‌شوند",
    "Share typing status" : "اشتراک‌گذاری وضعیت تایپ",
    "When off, all typing indicators will be hidden" : "در حالت خاموش، همه نشانگرهای تایپ مخفی می‌شوند",
    "Attachments folder" : "پوشه پیوست‌ها",
    "Toggle full screen" : "تغییر حالت تمام‌صفحه",
    "Return to Home screen" : "بازگشت به صفحه اصلی",
    "Search" : "جستجو",
    "Shortcuts while in a chat" : "میانبرهای داخل چت",
    "Focus the chat input" : "تمرکز روی ورودی چت",
    "Unfocus the chat input to use shortcuts" : "خارج شدن از تمرکز ورودی چت برای استفاده از میانبرها",
    "Edit your last message" : "ویرایش آخرین پیام شما",
    "Shortcuts while in a call" : "میانبرهای داخل تماس",
    "Camera on and off" : "روشن و خاموش کردن دوربین",
    "Microphone on and off" : "روشن و خاموش کردن میکروفون",
    "Raise or lower hand" : "بالا یا پایین آوردن دست",
    "Push to talk or push to mute" : "فشردن برای صحبت یا فشردن برای سکوت",
    "Zoom-in / zoom-out a screen share" : "بزرگ‌نمایی / کوچک‌نمایی اشتراک‌گذاری صفحه",
    "Mouse wheel" : "چرخ ماوس",
    "Start call silently" : "شروع تماس بی‌صدا",
    "Start call" : "شروع تماس",
    "End call" : "پایان تماس",
    "The server was updated, you cannot start or join a call." : "سرور به‌روزرسانی شد، نمی‌توانید تماسی را شروع یا به آن ملحق شوید.",
    "This call has just ended" : "این تماس به تازگی پایان یافته است",
    "You will be able to join the call only after a moderator starts it." : "تنها پس از شروع تماس توسط یک مدیر می‌توانید به تماس ملحق شوید.",
    "End call for everyone" : "پایان تماس برای همه",
    "Starting the recording" : "شروع ضبط",
    "Recording" : "در حال ضبط",
    "The call has been running for one hour." : "تماس به مدت یک ساعت در حال اجرا بوده است.",
    "Cancel recording start" : "لغو شروع ضبط",
    "Stop recording" : "توقف ضبط",
    "Raise hand" : "بالا بردن دست",
    "Raise hand (R)" : "بالا بردن دست (R)",
    "Lower hand" : "پایین آوردن دست",
    "Lower hand (R)" : "پایین آوردن دست (R)",
    "Send a reaction" : "ارسال واکنش",
    "React with {reaction}" : "واکنش با {reaction}",
    "All tasks done!" : "همه کارها انجام شد!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} of %n task","{done} of %n tasks"],
    "Add participants to this call" : "افزودن شرکت‌کنندگان به این تماس",
    "_%n participant in call_::_%n participants in call_" : ["%n participant in call","%n participants in call"],
    "Scheduled messages" : "پیام‌های زمان‌بندی شده",
    "You are not allowed to enable screensharing" : "شما مجاز به فعال‌سازی اشتراک‌گذاری صفحه نیستید",
    "No screensharing" : "بدون اشتراک‌گذاری صفحه",
    "Screensharing options" : "گزینه‌های اشتراک‌گذاری صفحه",
    "Enable screensharing" : "فعال‌سازی اشتراک‌گذاری صفحه",
    "Bad sent video and screen quality." : "کیفیت پایین ویدیو و صفحه ارسالی.",
    "Bad sent screen quality." : "کیفیت پایین صفحه ارسالی.",
    "Bad sent video quality." : "کیفیت پایین ویدیوی ارسالی.",
    "Bad sent audio, video and screen quality." : "کیفیت پایین صدا، ویدیو و صفحه ارسالی.",
    "Bad sent audio and screen quality." : "کیفیت پایین صدا و صفحه ارسالی.",
    "Bad sent audio and video quality." : "کیفیت پایین صدا و ویدیوی ارسالی.",
    "Bad sent audio quality." : "کیفیت صدای ارسالی ضعیف است.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "اتصال اینترنت یا سیستم شما مشغول است و ممکن است سایر شرکت‌کنندگان نتوانند صفحه شما را ببینند. برای بهبود وضعیت، هنگام اشتراک‌گذاری صفحه، محو کردن پس‌زمینه یا ویدیوی خود را غیرفعال کنید.",
    "Disable background blur" : "غیرفعال کردن محو کردن پس‌زمینه",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "اتصال اینترنت یا سیستم شما مشغول است و ممکن است سایر شرکت‌کنندگان نتوانند صفحه شما را ببینند. برای بهبود وضعیت، هنگام اشتراک‌گذاری صفحه، ویدیوی خود را غیرفعال کنید.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "اتصال اینترنت یا سیستم شما مشغول است و ممکن است سایر شرکت‌کنندگان نتوانند صفحه شما را ببینند.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "اتصال اینترنت یا سیستم شما مشغول است و ممکن است سایر شرکت‌کنندگان نتوانند شما را ببینند.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "اتصال اینترنت یا سیستم شما مشغول است و ممکن است سایر شرکت‌کنندگان نتوانند شما را ببینند و متوجه شوند. برای بهبود وضعیت، هنگام اشتراک‌گذاری صفحه، محو کردن پس‌زمینه یا ویدیوی خود را غیرفعال کنید.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "اتصال اینترنت یا سیستم شما مشغول است و ممکن است سایر شرکت‌کنندگان نتوانند شما را ببینند و متوجه شوند. برای بهبود وضعیت، هنگام اشتراک‌گذاری صفحه، ویدیوی خود را غیرفعال کنید.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "اتصال اینترنت یا سیستم شما مشغول است و ممکن است سایر شرکت‌کنندگان نتوانند شما را متوجه شوند و صفحه شما را ببینند. برای بهبود وضعیت، اشتراک‌گذاری صفحه خود را غیرفعال کنید.",
    "Disable screenshare" : "غیرفعال کردن اشتراک‌گذاری صفحه",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "اتصال اینترنت یا سیستم شما مشغول است و ممکن است سایر شرکت‌کنندگان نتوانند شما را ببینند و متوجه شوند. برای بهبود وضعیت، محو کردن پس‌زمینه یا ویدیوی خود را غیرفعال کنید.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "اتصال اینترنت یا سیستم شما مشغول است و ممکن است سایر شرکت‌کنندگان نتوانند شما را ببینند و متوجه شوند. برای بهبود وضعیت، ویدیوی خود را غیرفعال کنید.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "اتصال اینترنت یا سیستم شما مشغول است و ممکن است سایر شرکت‌کنندگان نتوانند شما را متوجه شوند.",
    "Screen sharing is not supported by your browser." : "اشتراک‌گذاری صفحه توسط مرورگر شما پشتیبانی نمی‌شود.",
    "Screen sharing requires the page to be loaded through HTTPS." : "اشتراک‌گذاری صفحه نیاز دارد که صفحه از طریق HTTPS بارگذاری شود.",
    "Screensharing requires the page to be loaded through HTTPS." : "اشتراک‌گذاری صفحه نیاز دارد که صفحه از طریق HTTPS بارگذاری شود.",
    "An error occurred while starting screensharing." : "هنگام شروع اشتراک‌گذاری صفحه خطایی رخ داد.",
    "Select virtual background" : "انتخاب پس‌زمینه مجازی",
    "Show your screen" : "نمایش صفحه شما",
    "Stop screensharing" : "توقف اشتراک‌گذاری صفحه",
    "Mute others" : "بی‌صدا کردن دیگران",
    "Start recording" : "شروع ضبط",
    "Set up breakout rooms" : "تنظیم اتاق‌های گروهی",
    "Download attendance list" : "دانلود لیست حضور",
    "Open Calendar" : "باز کردن تقویم",
    "Remove participant {name}" : "حذف شرکت‌کننده {name}",
    "Would you like to delete this conversation?" : "آیا می‌خواهید این گفتگو را حذف کنید؟",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["This conversation will be automatically deleted for everyone after %n day of inactivity.","This conversation will be automatically deleted for everyone after %n days of inactivity."],
    "Are you sure you want to delete this conversation?" : "آیا مطمئن هستید که می‌خواهید این گفتگو را حذف کنید؟",
    "Delete now" : "حذف کن",
    "Keep" : "نگه دار",
    "Open dialpad" : "باز کردن صفحه‌کلید شماره‌گیر",
    "Select a region" : "انتخاب یک منطقه",
    "Local time: {time}" : "زمان محلی: {time}",
    "Scheduled {datetime}" : "زمان‌بندی شده {datetime}",
    "Scheduled for {datetime}" : "زمان‌بندی شده برای {datetime}",
    "Search …" : "جستجو …",
    "Message without mention" : "پیام بدون اشاره",
    "Mention myself" : "اشاره به خودم",
    "Mention everyone" : "اشاره به همه",
    "Select a conversation" : "انتخاب یک گفتگو",
    "Select a mode" : "انتخاب یک حالت",
    "You do not have permissions to access this conversation." : "شما مجوز دسترسی به این گفتگو را ندارید.",
    "Join a different conversation or start a new one." : "به یک گفتگوی دیگر بپیوندید یا یک گفتگوی جدید شروع کنید.",
    "The conversation does not exist" : "گفتگو وجود ندارد",
    "Join a conversation or start a new one!" : "به یک گفتگو بپیوندید یا یک گفتگوی جدید شروع کنید!",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "این گفتگو در برگه دیگری باز شده است. نسخه فعلی سرور از باز کردن یک گفتگو در چند برگه پشتیبانی نمی‌کند.",
    "Creating and joining a conversation with \"{userid}\"" : "ایجاد و پیوستن به یک گفتگو با \"{userid}\"",
    "Join a conversation or start a new one" : "به یک گفتگو بپیوندید یا یک گفتگوی جدید شروع کنید",
    "Error while joining the conversation" : "خطا در هنگام پیوستن به گفتگو",
    "Another user" : "کاربر دیگر",
    "Hey! Are you using the list style or message bubbles?" : "سلام! از سبک لیست استفاده می‌کنی یا حباب‌های پیام؟",
    "Nextcloud URL" : "آدرس نکست‌کلود",
    "Nextcloud user" : "کاربر نکست‌کلود",
    "User password" : "رمز عبور کاربر",
    "Talk conversation" : "مکالمه Talk",
    "Skip TLS verification" : "رد کردن تأیید TLS",
    "Matrix server URL" : "آدرس سرور Matrix",
    "User" : "کاربر",
    "Matrix channel" : "کانال Matrix",
    "Mattermost server URL" : "آدرس سرور Mattermost",
    "Mattermost user" : "کاربر Mattermost",
    "Team name" : "نام تیم",
    "Channel name" : "نام کانال",
    "Rocket.Chat server URL" : "آدرس سرور Rocket.Chat",
    "User name or email address" : "نام کاربری یا آدرس ایمیل",
    "Rocket.Chat channel" : "کانال Rocket.Chat",
    "Zulip server URL" : "آدرس سرور Zulip",
    "Bot user name" : "نام کاربری ربات",
    "Bot API key" : "کلید API ربات",
    "Zulip channel" : "کانال Zulip",
    "API token" : "توکن API",
    "Slack channel" : "کانال Slack",
    "Server ID or name" : "شناسه یا نام سرور",
    "Channel ID (prefixed with \"ID:\") or name" : "شناسه کانال (با پیشوند \"ID:\") یا نام",
    "Channel" : "کانال",
    "Login" : "ورود",
    "Chat ID" : "شناسه چت",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "آدرس سرور IRC (مثال: chat.freenode.net:6667)",
    "Nickname" : "نام مستعار",
    "Connection password" : "رمز عبور اتصال",
    "IRC channel" : "کانال IRC",
    "Channel password" : "رمز عبور کانال",
    "NickServ nickname" : "نام مستعار NickServ",
    "NickServ password" : "رمز عبور NickServ",
    "Use TLS" : "استفاده از TLS",
    "Use SASL" : "استفاده از SASL",
    "Tenant ID" : "شناسه Tenant",
    "Client ID" : "شناسه Client",
    "Team ID" : "شناسه تیم",
    "Thread ID" : "شناسه Thread",
    "XMPP/Jabber server URL" : "آدرس سرور XMPP/Jabber",
    "MUC server URL" : "آدرس سرور MUC",
    "Jabber ID" : "شناسه Jabber",
    "Pinned messages" : "پیام‌های سنجاق‌شده",
    "Media" : "رسانه",
    "Polls" : "نظرسنجی‌ها",
    "Deck cards" : "کارت‌های کارتابل",
    "Voice messages" : "پیام‌های صوتی",
    "Locations" : "موقعیت‌ها",
    "Call recordings" : "ضبط تماس‌ها",
    "Audio" : "صدا",
    "Show all pinned messages" : "نمایش همه پیام‌های سنجاق‌شده",
    "Show all media" : "نمایش همه رسانه‌ها",
    "Show all files" : "نمایش همه فایل‌ها",
    "Show all polls" : "نمایش همه نظرسنجی‌ها",
    "Show all deck cards" : "نمایش همه کارت‌های کارتابل",
    "Show all voice messages" : "نمایش همه پیام‌های صوتی",
    "Show all locations" : "نمایش همه موقعیت‌ها",
    "Show all call recordings" : "نمایش همه ضبط تماس‌ها",
    "Show all audio" : "نمایش همه صداها",
    "Show all other" : "نمایش سایر موارد",
    "Follow conversation settings" : "پیروی از تنظیمات گفتگو",
    "Group" : "گروه",
    "Team" : "تیم",
    "You reconnected to the call" : "شما دوباره به تماس متصل شدید",
    "{actor} reconnected to the call" : "{actor} دوباره به تماس متصل شد",
    "You added {user0} and {user1}" : "شما {user0} و {user1} را اضافه کردید",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["You added {user0}, {user1} and %n more participant","You added {user0}, {user1} and %n more participants"],
    "An administrator added you and {user0}" : "یک مدیر شما و {user0} را اضافه کرد",
    "{actor} added you and {user0}" : "{actor} شما و {user0} را اضافه کرد",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["An administrator added you, {user0} and %n more participant","An administrator added you, {user0} and %n more participants"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} added you, {user0} and %n more participant","{actor} added you, {user0} and %n more participants"],
    "An administrator added {user0} and {user1}" : "یک مدیر {user0} و {user1} را اضافه کرد",
    "{actor} added {user0} and {user1}" : "{actor} {user0} و {user1} را اضافه کرد",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["An administrator added {user0}, {user1} and %n more participant","An administrator added {user0}, {user1} and %n more participants"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} added {user0}, {user1} and %n more participant","{actor} added {user0}, {user1} and %n more participants"],
    "You removed {user0} and {user1}" : "شما {user0} و {user1} را حذف کردید",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["You removed {user0}, {user1} and %n more participant","You removed {user0}, {user1} and %n more participants"],
    "An administrator removed you and {user0}" : "یک مدیر شما و {user0} را حذف کرد",
    "{actor} removed you and {user0}" : "{actor} شما و {user0} را حذف کرد",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["An administrator removed you, {user0} and %n more participant","An administrator removed you, {user0} and %n more participants"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} removed you, {user0} and %n more participant","{actor} removed you, {user0} and %n more participants"],
    "An administrator removed {user0} and {user1}" : "یک مدیر {user0} و {user1} را حذف کرد",
    "{actor} removed {user0} and {user1}" : "{actor} {user0} و {user1} را حذف کرد",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["An administrator removed {user0}, {user1} and %n more participant","An administrator removed {user0}, {user1} and %n more participants"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} removed {user0}, {user1} and %n more participant","{actor} removed {user0}, {user1} and %n more participants"],
    "You and {user0} joined the call" : "شما و {user0} به تماس پیوستید",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["You, {user0} and %n more participant joined the call","You, {user0} and %n more participants joined the call"],
    "{user0} and {user1} joined the call" : "{user0} و {user1} به تماس پیوستند",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} and %n more participant joined the call","{user0}, {user1} and %n more participants joined the call"],
    "You and {user0} left the call" : "شما و {user0} از تماس خارج شدید",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["You, {user0} and %n more participant left the call","You, {user0} and %n more participants left the call"],
    "{user0} and {user1} left the call" : "{user0} و {user1} از تماس خارج شدند",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} and %n more participant left the call","{user0}, {user1} and %n more participants left the call"],
    "You promoted {user0} and {user1} to moderators" : "شما {user0} و {user1} را به مدیران ارتقا دادید",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["You promoted {user0}, {user1} and %n more participant to moderators","You promoted {user0}, {user1} and %n more participants to moderators"],
    "An administrator promoted you and {user0} to moderators" : "یک مدیر شما و {user0} را به مدیران ارتقا داد",
    "{actor} promoted you and {user0} to moderators" : "{actor} شما و {user0} را به مدیران ارتقا داد",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["An administrator promoted you, {user0} and %n more participant to moderators","An administrator promoted you, {user0} and %n more participants to moderators"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} promoted you, {user0} and %n more participant to moderators","{actor} promoted you, {user0} and %n more participants to moderators"],
    "An administrator promoted {user0} and {user1} to moderators" : "یک مدیر {user0} و {user1} را به مدیران ارتقا داد",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} {user0} و {user1} را به مدیران ارتقا داد",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["An administrator promoted {user0}, {user1} and %n more participant to moderators","An administrator promoted {user0}, {user1} and %n more participants to moderators"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} promoted {user0}, {user1} and %n more participant to moderators","{actor} promoted {user0}, {user1} and %n more participants to moderators"],
    "You demoted {user0} and {user1} from moderators" : "شما {user0} و {user1} را از مدیریت عزل کردید",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["You demoted {user0}, {user1} and %n more participant from moderators","You demoted {user0}, {user1} and %n more participants from moderators"],
    "An administrator demoted you and {user0} from moderators" : "یک مدیر شما و {user0} را از مدیریت عزل کرد",
    "{actor} demoted you and {user0} from moderators" : "{actor} شما و {user0} را از مدیریت عزل کرد",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["An administrator demoted you, {user0} and %n more participant from moderators","An administrator demoted you, {user0} and %n more participants from moderators"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} demoted you, {user0} and %n more participant from moderators","{actor} demoted you, {user0} and %n more participants from moderators"],
    "An administrator demoted {user0} and {user1} from moderators" : "یک مدیر {user0} و {user1} را از مدیریت عزل کرد",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} {user0} و {user1} را از مدیریت عزل کرد",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["An administrator demoted {user0}, {user1} and %n more participant from moderators","An administrator demoted {user0}, {user1} and %n more participants from moderators"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} demoted {user0}, {user1} and %n more participant from moderators","{actor} demoted {user0}, {user1} and %n more participants from moderators"],
    "You:" : "شما:",
    "You: {lastMessage}" : "شما: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}، {absoluteDate}",
    "The server was updated." : "سرور به‌روزرسانی شد.",
    "(edited by you)" : "(ویرایش شده توسط شما)",
    "(edited by a deleted user)" : "(ویرایش شده توسط یک کاربر حذف‌شده)",
    "(edited by {moderator})" : "(ویرایش شده توسط {moderator})",
    "The recording failed. Please contact your administrator." : "ضبط انجام نشد. لطفاً با مدیر خود تماس بگیرید.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "شما در حال تلاش برای پیوستن به یک گفتگو هستید در حالی که یک نشست فعال در پنجره یا دستگاه دیگر دارید. این قابلیت در حال حاضر توسط نکست‌کلود تاک پشتیبانی نمی‌شود. چه کاری می‌خواهید انجام دهید؟",
    "Leave this page" : "ترک این صفحه",
    "Join here" : "پیوستن اینجا",
    "Deck card has been posted to {conversation}" : "کارت کارتابل به {conversation} ارسال شد",
    "An error occurred while posting deck card to conversation" : "هنگام ارسال کارت کارتابل به گفتگو خطایی رخ داد",
    "Post to a conversation" : "ارسال به یک گفتگو",
    "Post to conversation" : "ارسال به گفتگو",
    "Location has been posted to {conversation}" : "موقعیت مکانی به {conversation} ارسال شد",
    "An error occurred while posting location to conversation" : "هنگام ارسال موقعیت مکانی به گفتگو خطایی رخ داد",
    "Share to a conversation" : "اشتراک‌گذاری در یک گفتگو",
    "Share to conversation" : "اشتراک‌گذاری در گفتگو",
    "In conversation" : "در گفتگو",
    "Search in conversation: {conversation}" : "جستجو در گفتگو: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "درخواست‌های شما در حال حاضر به دلیل محافظت در برابر حملات brute force محدود شده است",
    "Error while clearing conversation history" : "خطا در پاک کردن تاریخچه گفتگو",
    "Error occurred while allowing guests" : "خطا در اجازه دادن به مهمانان",
    "Error occurred while disallowing guests" : "خطا در عدم اجازه به مهمانان",
    "Error occurred when restricting the conversation to moderator" : "خطا در محدود کردن گفتگو به مدیر",
    "Error occurred when opening the conversation to everyone" : "خطا در باز کردن گفتگو برای همه",
    "Conversation password has been saved" : "رمز عبور گفتگو ذخیره شد",
    "Conversation password has been removed" : "رمز عبور گفتگو حذف شد",
    "Error occurred while saving conversation password" : "خطا در ذخیره رمز عبور گفتگو",
    "Call recording is starting." : "ضبط تماس در حال شروع است.",
    "Call recording stopped while starting." : "ضبط تماس در حین شروع متوقف شد.",
    "Call recording stopped. You will be notified once the recording is available." : "ضبط تماس متوقف شد. پس از در دسترس بودن ضبط به شما اطلاع داده خواهد شد.",
    "Conversation picture set" : "تصویر گفتگو تنظیم شد",
    "Conversation picture deleted" : "عکس گفتگو حذف شد",
    "Could not delete the conversation picture" : "امکان حذف عکس گفتگو وجود نداشت",
    "Could not remove the automatic expiration" : "امکان حذف انقضای خودکار وجود نداشت",
    "Could not post message: {errorMessage}" : "امکان ارسال پیام وجود نداشت: {errorMessage}",
    "Participant is banned successfully" : "شرکت‌کننده با موفقیت مسدود شد",
    "Error while banning the participant" : "خطا در مسدود کردن شرکت‌کننده",
    "An error occurred while fetching the participants" : "هنگام دریافت لیست شرکت‌کنندگان خطایی رخ داد",
    "Could not send invitation to {actorId}" : "امکان ارسال دعوتنامه به {actorId} وجود نداشت",
    "Invitations sent" : "دعوتنامه‌ها ارسال شد",
    "Error occurred when sending invitations" : "هنگام ارسال دعوتنامه‌ها خطایی رخ داد",
    "Failed to join the conversation." : "پیوستن به گفتگو ناموفق بود",
    "An error occurred while creating breakout rooms" : "هنگام ایجاد اتاق‌های گروهی خطایی رخ داد",
    "An error occurred while re-ordering the attendees" : "هنگام مرتب‌سازی مجدد شرکت‌کنندگان خطایی رخ داد",
    "An error occurred while deleting breakout rooms" : "هنگام حذف اتاق‌های گروهی خطایی رخ داد",
    "An error occurred while starting breakout rooms" : "هنگام شروع اتاق‌های گروهی خطایی رخ داد",
    "An error occurred while stopping breakout rooms" : "هنگام توقف اتاق‌های گروهی خطایی رخ داد",
    "An error occurred while sending a message to the breakout rooms" : "هنگام ارسال پیام به اتاق‌های گروهی خطایی رخ داد",
    "An error occurred while requesting assistance" : "هنگام درخواست کمک خطایی رخ داد",
    "An error occurred while resetting the request for assistance" : "هنگام بازنشانی درخواست کمک خطایی رخ داد",
    "An error occurred while joining breakout room" : "هنگام پیوستن به اتاق گروهی خطایی رخ داد",
    "Failed to rename the thread" : "تغییر نام موضوع ناموفق بود",
    "Error renaming tag" : "خطا در تغییر نام برچسب",
    "Error deleting tag" : "خطا در حذف برچسب",
    "Error reordering tags" : "خطا در مرتب‌سازی مجدد برچسب‌ها",
    "Error fetching upcoming events" : "خطا در دریافت رویدادهای آینده",
    "Error fetching upcoming reminders" : "خطا در دریافت یادآوری‌های آینده",
    "An error occurred while accepting an invitation" : "هنگام پذیرش دعوتنامه خطایی رخ داد",
    "An error occurred while rejecting an invitation" : "هنگام رد دعوتنامه خطایی رخ داد",
    "{guest} (guest)" : "{guest} (مهمان)",
    "Poll draft has been saved" : "پیش‌نویس نظرسنجی ذخیره شد",
    "An error occurred while saving the draft" : "هنگام ذخیره پیش‌نویس خطایی رخ داد",
    "An error occurred while submitting your vote" : "هنگام ثبت رأی شما خطایی رخ داد",
    "An error occurred while ending the poll" : "هنگام پایان نظرسنجی خطایی رخ داد",
    "An error occurred while deleting the poll draft" : "هنگام حذف پیش‌نویس نظرسنجی خطایی رخ داد",
    "Poll \"{name}\" was created by {user}. Click to vote" : "نظرسنجی \"{name}\" توسط {user} ایجاد شد. برای رأی دادن کلیک کنید",
    "Failed to add reaction" : "افزودن واکنش ناموفق بود",
    "Failed to remove reaction" : "حذف واکنش ناموفق بود",
    "The server is in maintenance mode." : "سرور در حالت تعمیر و نگهداری است.",
    "Federated server was updated." : "سرور فدرال به‌روزرسانی شد.",
    "Error while uploading file \"{fileName}\"" : "خطا در آپلود فایل \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "فضای خالی کافی برای آپلود فایل \"{fileName}\" وجود ندارد",
    "You are not allowed to share files" : "شما مجاز به اشتراک‌گذاری فایل‌ها نیستید",
    "Error while sharing file" : "خطا در اشتراک‌گذاری فایل",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "مرورگری که استفاده می‌کنید به طور کامل توسط نکست‌کلود تاک پشتیبانی نمی‌شود. لطفاً از آخرین نسخه موزیلا فایرفاکس، مایکروسافت اج، گوگل کروم، اپرا یا اپل سافاری استفاده کنید.",
    "_%n hour_::_%n hours_" : ["%n hour","%n hours"],
    "_%n day_::_%n days_" : ["%n day","%n days"],
    "_%n week_::_%n weeks_" : ["%n week","%n weeks"],
    "_In %n hour_::_In %n hours_" : ["In %n hour","In %n hours"],
    "_%n minute _::_%n minutes_" : ["%n minute ","%n minutes"],
    "In {hours} and {minutes}" : "در {hours} و {minutes}",
    "_In %n minute_::_In %n minutes_" : ["In %n minute","In %n minutes"],
    "Later today – {timeLocale}" : "اواخر امروز – {timeLocale}",
    "Set time for later today" : "تنظیم زمان برای بعداً امروز",
    "Tomorrow – {timeLocale}" : "فردا – {timeLocale}",
    "Set time for tomorrow" : "تنظیم زمان برای فردا",
    "This weekend – {timeLocale}" : "این آخر هفته – {timeLocale}",
    "Set time for this weekend" : "تنظیم زمان برای این آخر هفته",
    "Next week – {timeLocale}" : "هفته آینده – {timeLocale}",
    "Set time for next week" : "تنظیم زمان برای هفته آینده",
    "Message link copied to clipboard" : "لینک پیام در کلیپ‌بورد کپی شد",
    "Conversation link copied to clipboard" : "لینک گفتگو در کلیپ‌بورد کپی شد",
    "The link could not be copied" : "لینک قابل کپی شدن نبود",
    "Error while parsing a PROPFIND error" : "خطا در تجزیه خطای PROPFIND",
    "Sending signaling message has failed" : "ارسال پیام سیگنالینگ ناموفق بود",
    "Lost connection to signaling server. Trying to reconnect." : "اتصال به سرور سیگنالینگ قطع شد. تلاش برای اتصال مجدد...",
    "Lost connection to signaling server." : "اتصال به سرور سیگنالینگ قطع شد.",
    "Connecting is taking longer than expected …" : "برقراری اتصال بیش از حد انتظار طول می‌کشد …",
    "Failed to connect. Retrying …" : "اتصال ناموفق بود. در حال تلاش مجدد …",
    "Failed to connect. The signaling server may be set up incorrectly" : "اتصال ناموفق بود. ممکن است سرور سیگنالینگ به درستی پیکربندی نشده باشد",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "سرور سیگنالینگ پیکربندی شده باید به‌روزرسانی شود تا با این نسخه از Talk سازگار باشد. لطفاً با مدیر خود تماس بگیرید.",
    "Please restart the app." : "لطفاً برنامه را مجدداً راه‌اندازی کنید.",
    "Please reload the page." : "لطفاً صفحه را بارگذاری مجدد کنید.",
    "Please try to restart the app." : "لطفاً سعی کنید برنامه را مجدداً راه‌اندازی کنید.",
    "Please try to reload the page." : "لطفاً سعی کنید صفحه را بارگذاری مجدد کنید.",
    "Do not disturb" : "مزاحم نشوید",
    "Away" : "دور از دسترس",
    "Microphone {number}" : "میکروفون {number}",
    "Camera {number}" : "دوربین {number}",
    "Speaker {number}" : "بلندگو {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "به نظر می‌رسد در حال صحبت کردن هستید در حالی که صدا قطع است، لطفاً صدا را فعال کنید تا دیگران شما را بشنوند",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "امکان برقراری اتصال با حداقل یک شرکت‌کننده وجود نداشت. ممکن است برای سناریوی شما به سرور TURN نیاز باشد. لطفاً از مدیر خود بخواهید یکی را مطابق {linkstart}این مستندات{linkend} راه‌اندازی کند.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "این کار بیشتر از حد انتظار طول می‌کشد. آیا مجوزهای رسانه قبلاً اعطا (یا رد) شده‌اند؟ اگر بله، لطفاً مرورگر خود را مجدداً راه‌اندازی کنید، زیرا صدا و تصویر با مشکل مواجه شده‌اند",
    "Access to microphone & camera is only possible with HTTPS" : "دسترسی به میکروفون و دوربین فقط با HTTPS امکان‌پذیر است",
    "Please move your setup to HTTPS" : "لطفاً تنظیمات خود را به HTTPS منتقل کنید",
    "Access to microphone & camera was denied" : "دسترسی به میکروفون و دوربین رد شد",
    "WebRTC is not supported in your browser" : "WebRTC در مرورگر شما پشتیبانی نمی‌شود",
    "Please use a different browser like Firefox or Chrome" : "لطفاً از مرورگر دیگری مانند Firefox یا Chrome استفاده کنید",
    "Error while accessing microphone & camera" : "خطا در دسترسی به میکروفون و دوربین",
    "%s Talk on your mobile devices" : "%s Talk را روی دستگاه‌های همراه خود داشته باشید",
    "Join conversations at any time, anywhere, on any device." : "در هر زمان، هر مکان و روی هر دستگاهی به گفتگوها بپیوندید.",
    "Android app" : "برنامه Android",
    "iOS app" : "برنامه iOS",
    "__language_name__" : "__language_name__",
    "Webhook Demo" : "نمایش Webhook",
    "Call summary (%s)" : "خلاصه تماس (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "ربات خلاصه تماس پس از تماس یک پیام کلی ارسال می‌کند که همه شرکت‌کنندگان را فهرست کرده و وظایف را مشخص می‌کند",
    "Tasks" : "وظایف",
    "Notes" : "یادداشت‌ها",
    "Reports" : "گزارش‌ها",
    "Decisions" : "تصمیمات",
    "Agenda" : "دستور جلسه",
    "Call summary" : "خلاصه تماس",
    "Call summary - {title}" : "خلاصه تماس - {title}",
    "Talk to %s" : "گفتگو با %s",
    "Missing email field in header line" : "فیلد ایمیل در خط سربرگ وجود ندارد",
    "Talk conversation for event" : "گفتگوی Talk برای رویداد",
    "Client Push is installed, this improves the performance of desktop clients." : "Client Push نصب شده است که عملکرد کلاینت‌های دسکتاپ را بهبود می‌بخشد.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} نصب نشده است که ممکن است هنگام استفاده از کلاینت‌های دسکتاپ مشکلات عملکردی ایجاد کند.",
    "Next meeting" : "جلسه بعدی",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "از تقویم خود یک جلسه برنامه‌ریزی کنید. برای نمایش در اینجا، باید یک گفتگوی Talk به عنوان مکان تنظیم شود.",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "فرمت محتوا مقادیر جدا شده با کاما (CSV) است:<br/>- خط سربرگ الزامی است و باید با <samp>\"name\",\"email\"</samp> یا فقط <samp>\"email\"</samp> مطابقت داشته باشد<br/>- هر خط یک ورودی (مثلاً <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Join conversations from remote Nextcloud servers" : "پیوستن به گفتگوها از سرورهای نکست‌کلود راه دور",
    "Your default media state has been saved" : "وضعیت پیش‌فرض رسانه شما ذخیره شد",
    "Set reminder for later today" : "تنظیم یادآوری برای بعداً امروز",
    "Set reminder for tomorrow" : "تنظیم یادآوری برای فردا",
    "Set reminder for this weekend" : "تنظیم یادآوری برای این آخر هفته",
    "Set reminder for next week" : "تنظیم یادآوری برای هفته آینده",
    "Generate summary" : "تولید خلاصه",
    "Open poll • You voted already" : "نظرسنجی باز • شما قبلاً رأی داده‌اید",
    "Open poll • Click to vote" : "نظرسنجی باز • برای رأی دادن کلیک کنید",
    "Poll • Ended" : "نظرسنجی • پایان‌یافته",
    "Talk recording from {time} ({conversation})" : "ضبط Talk از {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["نتایج نظرسنجی • %n رأی","نتایج نظرسنجی • %n رأی"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["نظرسنجی باز • %n رأی","نظرسنجی باز • %n رأی"],
    "Submit vote" : "ثبت رأی",
    "Your privacy setting has been saved" : "تنظیم حریم خصوصی شما ذخیره شد",
    "Your personal setting has been saved" : "تنظیمات شخصی شما ذخیره شد",
    "Failed to save sounds setting" : "ذخیره تنظیمات صدا ناموفق بود",
    "Sounds setting saved" : "تنظیمات صدا ذخیره شد",
    "Always shown if recording consent is required" : "در صورت نیاز به رضایت برای ضبط، همیشه نمایش داده می‌شود",
    "Nextcloud Talk was updated, you cannot start or join a call." : "نکست‌کلود Talk به‌روزرسانی شد، نمی‌توانید تماسی را شروع یا به آن بپیوندید.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "شما در پنجره یا دستگاه دیگری به گفتگو پیوستید. این قابلیت در حال حاضر توسط نکست‌کلود Talk پشتیبانی نمی‌شود، بنابراین این نشست بسته شد.",
    "Nextcloud Talk was updated." : "نکست‌کلود Talk به‌روزرسانی شد.",
    "Nextcloud is in maintenance mode." : "نکست‌کلود در حالت تعمیر و نگهداری است.",
    "Nextcloud Talk Federation was updated." : "نکست‌کلود Talk Federation به‌روزرسانی شد.",
    "Enable live translation" : "فعال‌سازی ترجمه زنده",
    "_Open poll • %n vote • Your vote is anonymous_::_Open poll • %n votes • Your vote is anonymous_" : ["نظرسنجی باز • %n رأی • رأی شما ناشناس است","نظرسنجی باز • %n رأی • رأی شما ناشناس است"],
    "Open poll • You voted already • Your vote is anonymous" : "نظرسنجی باز • شما قبلاً رأی داده‌اید • رأی شما ناشناس است",
    "Open poll • Your vote is anonymous" : "نظرسنجی باز • رأی شما ناشناس است",
    "I picked list style" : "من حالت لیستی را انتخاب کردم",
    "Hey! Are you using Talk in list style or with message bubbles?" : "سلام! آیا از Talk در حالت لیستی یا با حباب‌های پیام استفاده می‌کنید؟"
},
"nplurals=2; plural=(n > 1);");
